import { ATN, DFA, FailedPredicateException, Parser, ParserRuleContext, TerminalNode, TokenStream } from 'antlr4';
import CypherParserListener from "./CypherParserListener.js";
import CypherParserVisitor from "./CypherParserVisitor.js";
export default class CypherParser extends Parser {
    static readonly SPACE = 1;
    static readonly SINGLE_LINE_COMMENT = 2;
    static readonly DECIMAL_DOUBLE = 3;
    static readonly UNSIGNED_DECIMAL_INTEGER = 4;
    static readonly UNSIGNED_HEX_INTEGER = 5;
    static readonly UNSIGNED_OCTAL_INTEGER = 6;
    static readonly ACCESS = 7;
    static readonly ACTIVE = 8;
    static readonly ADMIN = 9;
    static readonly ADMINISTRATOR = 10;
    static readonly ALIAS = 11;
    static readonly ALIASES = 12;
    static readonly ALL_SHORTEST_PATH = 13;
    static readonly ALL = 14;
    static readonly ALTER = 15;
    static readonly AND = 16;
    static readonly ANY = 17;
    static readonly ARRAY = 18;
    static readonly AS = 19;
    static readonly ASC = 20;
    static readonly ASSERT = 21;
    static readonly ASSIGN = 22;
    static readonly AT = 23;
    static readonly BAR = 24;
    static readonly BINDINGS = 25;
    static readonly BOOL = 26;
    static readonly BOOLEAN = 27;
    static readonly BOOSTED = 28;
    static readonly BREAK = 29;
    static readonly BRIEF = 30;
    static readonly BTREE = 31;
    static readonly BUILT = 32;
    static readonly BY = 33;
    static readonly CALL = 34;
    static readonly CASE = 35;
    static readonly CHANGE = 36;
    static readonly CIDR = 37;
    static readonly COLLECT = 38;
    static readonly COLON = 39;
    static readonly COLONCOLON = 40;
    static readonly COMMA = 41;
    static readonly COMMAND = 42;
    static readonly COMMANDS = 43;
    static readonly COMMIT = 44;
    static readonly COMPOSITE = 45;
    static readonly CONSTRAINT = 46;
    static readonly CONSTRAINTS = 47;
    static readonly CONTAINS = 48;
    static readonly COPY = 49;
    static readonly CONTINUE = 50;
    static readonly COUNT = 51;
    static readonly CREATE = 52;
    static readonly CSV = 53;
    static readonly CURRENT = 54;
    static readonly DATA = 55;
    static readonly DATABASE = 56;
    static readonly DATABASES = 57;
    static readonly DATE = 58;
    static readonly DATETIME = 59;
    static readonly DBMS = 60;
    static readonly DEALLOCATE = 61;
    static readonly DEFAULT = 62;
    static readonly DEFINED = 63;
    static readonly DELETE = 64;
    static readonly DENY = 65;
    static readonly DESC = 66;
    static readonly DESTROY = 67;
    static readonly DETACH = 68;
    static readonly DIFFERENT = 69;
    static readonly DOLLAR = 70;
    static readonly DISTINCT = 71;
    static readonly DIVIDE = 72;
    static readonly DOT = 73;
    static readonly DOTDOT = 74;
    static readonly DRIVER = 75;
    static readonly DROP = 76;
    static readonly DRYRUN = 77;
    static readonly DUMP = 78;
    static readonly DURATION = 79;
    static readonly EACH = 80;
    static readonly EDGE = 81;
    static readonly ENABLE = 82;
    static readonly ELEMENT = 83;
    static readonly ELEMENTS = 84;
    static readonly ELSE = 85;
    static readonly ENCRYPTED = 86;
    static readonly END = 87;
    static readonly ENDS = 88;
    static readonly EQ = 89;
    static readonly EXECUTABLE = 90;
    static readonly EXECUTE = 91;
    static readonly EXIST = 92;
    static readonly EXISTENCE = 93;
    static readonly EXISTS = 94;
    static readonly ERROR = 95;
    static readonly FAIL = 96;
    static readonly FALSE = 97;
    static readonly FIELDTERMINATOR = 98;
    static readonly FLOAT = 99;
    static readonly FOR = 100;
    static readonly FOREACH = 101;
    static readonly FROM = 102;
    static readonly FULLTEXT = 103;
    static readonly FUNCTION = 104;
    static readonly FUNCTIONS = 105;
    static readonly GE = 106;
    static readonly GRANT = 107;
    static readonly GRAPH = 108;
    static readonly GRAPHS = 109;
    static readonly GROUP = 110;
    static readonly GROUPS = 111;
    static readonly GT = 112;
    static readonly HEADERS = 113;
    static readonly HOME = 114;
    static readonly IF = 115;
    static readonly IMPERSONATE = 116;
    static readonly IMMUTABLE = 117;
    static readonly IN = 118;
    static readonly INDEX = 119;
    static readonly INDEXES = 120;
    static readonly INF = 121;
    static readonly INFINITY = 122;
    static readonly INT = 123;
    static readonly INTEGER = 124;
    static readonly IS = 125;
    static readonly JOIN = 126;
    static readonly KEY = 127;
    static readonly LABEL = 128;
    static readonly LABELS = 129;
    static readonly AMPERSAND = 130;
    static readonly EXCLAMATION_MARK = 131;
    static readonly LBRACKET = 132;
    static readonly LCURLY = 133;
    static readonly LE = 134;
    static readonly LIMITROWS = 135;
    static readonly LIST = 136;
    static readonly LOAD = 137;
    static readonly LOCAL = 138;
    static readonly LOOKUP = 139;
    static readonly LPAREN = 140;
    static readonly LT = 141;
    static readonly MANAGEMENT = 142;
    static readonly MAP = 143;
    static readonly MATCH = 144;
    static readonly MERGE = 145;
    static readonly MINUS = 146;
    static readonly PERCENT = 147;
    static readonly NEQ = 148;
    static readonly NEQ2 = 149;
    static readonly NAME = 150;
    static readonly NAMES = 151;
    static readonly NAN = 152;
    static readonly NEW = 153;
    static readonly NODE = 154;
    static readonly NODES = 155;
    static readonly NONE = 156;
    static readonly NOT = 157;
    static readonly NOTHING = 158;
    static readonly NOWAIT = 159;
    static readonly NULL = 160;
    static readonly OF = 161;
    static readonly ON = 162;
    static readonly ONLY = 163;
    static readonly OPTIONAL = 164;
    static readonly OPTIONS = 165;
    static readonly OPTION = 166;
    static readonly OR = 167;
    static readonly ORDER = 168;
    static readonly OUTPUT = 169;
    static readonly PASSWORD = 170;
    static readonly PASSWORDS = 171;
    static readonly PATH = 172;
    static readonly PATHS = 173;
    static readonly PERIODIC = 174;
    static readonly PLAINTEXT = 175;
    static readonly PLUS = 176;
    static readonly PLUSEQUAL = 177;
    static readonly POINT = 178;
    static readonly POPULATED = 179;
    static readonly POW = 180;
    static readonly PRIMARY = 181;
    static readonly PRIMARIES = 182;
    static readonly PRIVILEGE = 183;
    static readonly PRIVILEGES = 184;
    static readonly PROCEDURE = 185;
    static readonly PROCEDURES = 186;
    static readonly PROPERTIES = 187;
    static readonly PROPERTY = 188;
    static readonly QUESTION = 189;
    static readonly RANGE = 190;
    static readonly RBRACKET = 191;
    static readonly RCURLY = 192;
    static readonly READ = 193;
    static readonly REALLOCATE = 194;
    static readonly REDUCE = 195;
    static readonly RENAME = 196;
    static readonly REGEQ = 197;
    static readonly REL = 198;
    static readonly RELATIONSHIP = 199;
    static readonly RELATIONSHIPS = 200;
    static readonly REMOVE = 201;
    static readonly REPEATABLE = 202;
    static readonly REPLACE = 203;
    static readonly REPORT = 204;
    static readonly REQUIRE = 205;
    static readonly REQUIRED = 206;
    static readonly RETURN = 207;
    static readonly REVOKE = 208;
    static readonly ROLE = 209;
    static readonly ROLES = 210;
    static readonly ROW = 211;
    static readonly ROWS = 212;
    static readonly RPAREN = 213;
    static readonly SCAN = 214;
    static readonly SEC = 215;
    static readonly SECOND = 216;
    static readonly SECONDARY = 217;
    static readonly SECONDARIES = 218;
    static readonly SECONDS = 219;
    static readonly SEEK = 220;
    static readonly SEMICOLON = 221;
    static readonly SERVER = 222;
    static readonly SERVERS = 223;
    static readonly SET = 224;
    static readonly SETTING = 225;
    static readonly SETTINGS = 226;
    static readonly SHORTEST_PATH = 227;
    static readonly SHORTEST = 228;
    static readonly SHOW = 229;
    static readonly SIGNED = 230;
    static readonly SINGLE = 231;
    static readonly SKIPROWS = 232;
    static readonly START = 233;
    static readonly STARTS = 234;
    static readonly STATUS = 235;
    static readonly STOP = 236;
    static readonly STRING = 237;
    static readonly SUPPORTED = 238;
    static readonly SUSPENDED = 239;
    static readonly TARGET = 240;
    static readonly TERMINATE = 241;
    static readonly TEXT = 242;
    static readonly THEN = 243;
    static readonly TIME = 244;
    static readonly TIMES = 245;
    static readonly TIMESTAMP = 246;
    static readonly TIMEZONE = 247;
    static readonly TO = 248;
    static readonly TOPOLOGY = 249;
    static readonly TRANSACTION = 250;
    static readonly TRANSACTIONS = 251;
    static readonly TRAVERSE = 252;
    static readonly TRUE = 253;
    static readonly TYPE = 254;
    static readonly TYPED = 255;
    static readonly TYPES = 256;
    static readonly UNION = 257;
    static readonly UNIQUE = 258;
    static readonly UNIQUENESS = 259;
    static readonly UNWIND = 260;
    static readonly URL = 261;
    static readonly USE = 262;
    static readonly USER = 263;
    static readonly USERS = 264;
    static readonly USING = 265;
    static readonly VALUE = 266;
    static readonly VARCHAR = 267;
    static readonly VERBOSE = 268;
    static readonly VERTEX = 269;
    static readonly WAIT = 270;
    static readonly WHEN = 271;
    static readonly WHERE = 272;
    static readonly WITH = 273;
    static readonly WITHOUT = 274;
    static readonly WRITE = 275;
    static readonly XOR = 276;
    static readonly YIELD = 277;
    static readonly ZONED = 278;
    static readonly EXPLAIN = 279;
    static readonly PROFILE = 280;
    static readonly IDENTIFIER = 281;
    static readonly ErrorChar = 282;
    static readonly ARROW_LINE = 283;
    static readonly ARROW_LEFT_HEAD = 284;
    static readonly ARROW_RIGHT_HEAD = 285;
    static readonly FORMAL_COMMENT = 286;
    static readonly STRING_LITERAL1 = 287;
    static readonly STRING_LITERAL2 = 288;
    static readonly MULTI_LINE_COMMENT = 289;
    static readonly ESCAPED_SYMBOLIC_NAME = 290;
    static readonly MORE1 = 291;
    static readonly STRING1_OPEN = 292;
    static readonly STRING2_OPEN = 293;
    static readonly ESCAPED_SYMBOLIC_NAME_OPEN = 294;
    static readonly MORE3 = 295;
    static readonly MORE4 = 296;
    static readonly MORE5 = 297;
    static readonly MORE6 = 298;
    static readonly MORE7 = 299;
    static readonly MORE8 = 300;
    static readonly MORE9 = 301;
    static readonly MORE10 = 302;
    static readonly MORE11 = 303;
    static readonly MORE24 = 304;
    static readonly EOF: number;
    static readonly RULE_statements = 0;
    static readonly RULE_statement = 1;
    static readonly RULE_preparserOption = 2;
    static readonly RULE_singleQueryOrCommand = 3;
    static readonly RULE_singleQueryOrCommandWithUseClause = 4;
    static readonly RULE_periodicCommitQueryHintFailure = 5;
    static readonly RULE_regularQuery = 6;
    static readonly RULE_union = 7;
    static readonly RULE_singleQuery = 8;
    static readonly RULE_singleQueryWithUseClause = 9;
    static readonly RULE_clause = 10;
    static readonly RULE_useClause = 11;
    static readonly RULE_returnClause = 12;
    static readonly RULE_returnBody = 13;
    static readonly RULE_returnItem = 14;
    static readonly RULE_returnItems = 15;
    static readonly RULE_orderItem = 16;
    static readonly RULE_skip = 17;
    static readonly RULE_limit = 18;
    static readonly RULE_whereClause = 19;
    static readonly RULE_withClause = 20;
    static readonly RULE_createClause = 21;
    static readonly RULE_setClause = 22;
    static readonly RULE_setItem = 23;
    static readonly RULE_removeClause = 24;
    static readonly RULE_removeItem = 25;
    static readonly RULE_deleteClause = 26;
    static readonly RULE_matchClause = 27;
    static readonly RULE_matchMode = 28;
    static readonly RULE_hints = 29;
    static readonly RULE_indexHintBody = 30;
    static readonly RULE_mergeClause = 31;
    static readonly RULE_unwindClause = 32;
    static readonly RULE_callClause = 33;
    static readonly RULE_procedureName = 34;
    static readonly RULE_procedureArgument = 35;
    static readonly RULE_procedureResultItem = 36;
    static readonly RULE_loadCSVClause = 37;
    static readonly RULE_foreachClause = 38;
    static readonly RULE_subqueryClause = 39;
    static readonly RULE_subqueryInTransactionsParameters = 40;
    static readonly RULE_subqueryInTransactionsBatchParameters = 41;
    static readonly RULE_subqueryInTransactionsErrorParameters = 42;
    static readonly RULE_subqueryInTransactionsReportParameters = 43;
    static readonly RULE_patternList = 44;
    static readonly RULE_pattern = 45;
    static readonly RULE_quantifier = 46;
    static readonly RULE_anonymousPattern = 47;
    static readonly RULE_shortestPathPattern = 48;
    static readonly RULE_maybeQuantifiedRelationshipPattern = 49;
    static readonly RULE_patternElement = 50;
    static readonly RULE_pathPatternAtoms = 51;
    static readonly RULE_selector = 52;
    static readonly RULE_pathPatternNonEmpty = 53;
    static readonly RULE_nodePattern = 54;
    static readonly RULE_parenthesizedPath = 55;
    static readonly RULE_nodeLabels = 56;
    static readonly RULE_labelExpressionPredicate = 57;
    static readonly RULE_labelOrRelType = 58;
    static readonly RULE_labelOrRelTypes = 59;
    static readonly RULE_properties = 60;
    static readonly RULE_relationshipPattern = 61;
    static readonly RULE_leftArrow = 62;
    static readonly RULE_arrowLine = 63;
    static readonly RULE_rightArrow = 64;
    static readonly RULE_pathLength = 65;
    static readonly RULE_pathLengthLiteral = 66;
    static readonly RULE_labelExpression = 67;
    static readonly RULE_labelExpression4 = 68;
    static readonly RULE_labelExpression4Is = 69;
    static readonly RULE_labelExpression3 = 70;
    static readonly RULE_labelExpression3Is = 71;
    static readonly RULE_labelExpression2 = 72;
    static readonly RULE_labelExpression2Is = 73;
    static readonly RULE_labelExpression1 = 74;
    static readonly RULE_labelExpression1Is = 75;
    static readonly RULE_expression = 76;
    static readonly RULE_expression12 = 77;
    static readonly RULE_expression11 = 78;
    static readonly RULE_expression10 = 79;
    static readonly RULE_expression9 = 80;
    static readonly RULE_expression8 = 81;
    static readonly RULE_expression7 = 82;
    static readonly RULE_comparisonExpression6 = 83;
    static readonly RULE_expression6 = 84;
    static readonly RULE_expression5 = 85;
    static readonly RULE_expression4 = 86;
    static readonly RULE_expression3 = 87;
    static readonly RULE_expression2 = 88;
    static readonly RULE_postFix1 = 89;
    static readonly RULE_property = 90;
    static readonly RULE_propertyExpression = 91;
    static readonly RULE_expression1 = 92;
    static readonly RULE_literal = 93;
    static readonly RULE_caseExpression = 94;
    static readonly RULE_listComprehension = 95;
    static readonly RULE_listComprehensionWhereAndBar = 96;
    static readonly RULE_patternComprehension = 97;
    static readonly RULE_reduceExpression = 98;
    static readonly RULE_allExpression = 99;
    static readonly RULE_anyExpression = 100;
    static readonly RULE_noneExpression = 101;
    static readonly RULE_singleExpression = 102;
    static readonly RULE_patternExpression = 103;
    static readonly RULE_shortestPathExpression = 104;
    static readonly RULE_mapProjection = 105;
    static readonly RULE_mapProjectionItem = 106;
    static readonly RULE_existsExpression = 107;
    static readonly RULE_countExpression = 108;
    static readonly RULE_collectExpression = 109;
    static readonly RULE_stringLiteral = 110;
    static readonly RULE_numberLiteral = 111;
    static readonly RULE_signedIntegerLiteral = 112;
    static readonly RULE_listLiteral = 113;
    static readonly RULE_mapLiteral = 114;
    static readonly RULE_propertyKeyName = 115;
    static readonly RULE_parameter = 116;
    static readonly RULE_parameterName = 117;
    static readonly RULE_functionInvocation = 118;
    static readonly RULE_functionName = 119;
    static readonly RULE_functionArgument = 120;
    static readonly RULE_namespace = 121;
    static readonly RULE_variableList1 = 122;
    static readonly RULE_variable = 123;
    static readonly RULE_symbolicNameList1 = 124;
    static readonly RULE_createCommand = 125;
    static readonly RULE_command = 126;
    static readonly RULE_commandWithUseGraph = 127;
    static readonly RULE_dropCommand = 128;
    static readonly RULE_alterCommand = 129;
    static readonly RULE_showCommand = 130;
    static readonly RULE_terminateCommand = 131;
    static readonly RULE_showAllCommand = 132;
    static readonly RULE_showNodeCommand = 133;
    static readonly RULE_showRelationshipCommand = 134;
    static readonly RULE_showRelCommand = 135;
    static readonly RULE_showPropertyCommand = 136;
    static readonly RULE_yieldItem = 137;
    static readonly RULE_yieldClause = 138;
    static readonly RULE_showIndexesAllowBrief = 139;
    static readonly RULE_showIndexesNoBrief = 140;
    static readonly RULE_showConstraintsAllowBriefAndYield = 141;
    static readonly RULE_showConstraintsAllowBrief = 142;
    static readonly RULE_showConstraintsAllowYield = 143;
    static readonly RULE_showProcedures = 144;
    static readonly RULE_showFunctions = 145;
    static readonly RULE_showTransactions = 146;
    static readonly RULE_terminateTransactions = 147;
    static readonly RULE_showOrTerminateTransactions = 148;
    static readonly RULE_stringsOrExpression = 149;
    static readonly RULE_showSettings = 150;
    static readonly RULE_createConstraint = 151;
    static readonly RULE_cypherTypeName = 152;
    static readonly RULE_cypherTypeNameList = 153;
    static readonly RULE_cypherTypeNamePart = 154;
    static readonly RULE_constraintNodePattern = 155;
    static readonly RULE_constraintRelPattern = 156;
    static readonly RULE_createConstraintNodeCheck = 157;
    static readonly RULE_createConstraintRelCheck = 158;
    static readonly RULE_dropConstraint = 159;
    static readonly RULE_dropConstraintNodeCheck = 160;
    static readonly RULE_createIndex = 161;
    static readonly RULE_oldCreateIndex = 162;
    static readonly RULE_createIndex_ = 163;
    static readonly RULE_createFulltextIndex = 164;
    static readonly RULE_createLookupIndex = 165;
    static readonly RULE_lookupIndexFunctionName = 166;
    static readonly RULE_dropIndex = 167;
    static readonly RULE_propertyList = 168;
    static readonly RULE_renameCommand = 169;
    static readonly RULE_grantCommand = 170;
    static readonly RULE_revokeCommand = 171;
    static readonly RULE_enableServerCommand = 172;
    static readonly RULE_alterServer = 173;
    static readonly RULE_renameServer = 174;
    static readonly RULE_dropServer = 175;
    static readonly RULE_showServers = 176;
    static readonly RULE_allocationCommand = 177;
    static readonly RULE_deallocateDatabaseFromServers = 178;
    static readonly RULE_reallocateDatabases = 179;
    static readonly RULE_createRole = 180;
    static readonly RULE_dropRole = 181;
    static readonly RULE_renameRole = 182;
    static readonly RULE_showRoles = 183;
    static readonly RULE_grantRole = 184;
    static readonly RULE_revokeRole = 185;
    static readonly RULE_createUser = 186;
    static readonly RULE_dropUser = 187;
    static readonly RULE_renameUser = 188;
    static readonly RULE_alterCurrentUser = 189;
    static readonly RULE_alterUser = 190;
    static readonly RULE_setPassword = 191;
    static readonly RULE_passwordExpression = 192;
    static readonly RULE_passwordChangeRequired = 193;
    static readonly RULE_userStatus = 194;
    static readonly RULE_homeDatabase = 195;
    static readonly RULE_showUsers = 196;
    static readonly RULE_showCurrentUser = 197;
    static readonly RULE_showSupportedPrivileges = 198;
    static readonly RULE_showPrivileges = 199;
    static readonly RULE_showRolePrivileges = 200;
    static readonly RULE_showUserPrivileges = 201;
    static readonly RULE_grantRoleManagement = 202;
    static readonly RULE_revokeRoleManagement = 203;
    static readonly RULE_roleManagementPrivilege = 204;
    static readonly RULE_grantPrivilege = 205;
    static readonly RULE_denyPrivilege = 206;
    static readonly RULE_revokePrivilege = 207;
    static readonly RULE_privilege = 208;
    static readonly RULE_allPrivilege = 209;
    static readonly RULE_allPrivilegeType = 210;
    static readonly RULE_allPrivilegeTarget = 211;
    static readonly RULE_createPrivilege = 212;
    static readonly RULE_dropPrivilege = 213;
    static readonly RULE_loadPrivilege = 214;
    static readonly RULE_showPrivilege = 215;
    static readonly RULE_setPrivilege = 216;
    static readonly RULE_removePrivilege = 217;
    static readonly RULE_writePrivilege = 218;
    static readonly RULE_databasePrivilege = 219;
    static readonly RULE_dbmsPrivilege = 220;
    static readonly RULE_executeFunctionQualifier = 221;
    static readonly RULE_executeProcedureQualifier = 222;
    static readonly RULE_settingQualifier = 223;
    static readonly RULE_globs = 224;
    static readonly RULE_qualifiedGraphPrivilegesWithProperty = 225;
    static readonly RULE_qualifiedGraphPrivileges = 226;
    static readonly RULE_labelResource = 227;
    static readonly RULE_propertyResource = 228;
    static readonly RULE_graphQualifier = 229;
    static readonly RULE_createDatabase = 230;
    static readonly RULE_options_ = 231;
    static readonly RULE_createCompositeDatabase = 232;
    static readonly RULE_dropDatabase = 233;
    static readonly RULE_alterDatabase = 234;
    static readonly RULE_startDatabase = 235;
    static readonly RULE_stopDatabase = 236;
    static readonly RULE_waitClause = 237;
    static readonly RULE_showDatabase = 238;
    static readonly RULE_databaseScope = 239;
    static readonly RULE_graphScope = 240;
    static readonly RULE_createAlias = 241;
    static readonly RULE_dropAlias = 242;
    static readonly RULE_alterAlias = 243;
    static readonly RULE_showAliases = 244;
    static readonly RULE_symbolicAliasNameList = 245;
    static readonly RULE_symbolicAliasName = 246;
    static readonly RULE_symbolicNameOrStringParameterList = 247;
    static readonly RULE_symbolicNameOrStringParameter = 248;
    static readonly RULE_glob = 249;
    static readonly RULE_globRecursive = 250;
    static readonly RULE_globPart = 251;
    static readonly RULE_stringImage = 252;
    static readonly RULE_stringList = 253;
    static readonly RULE_stringToken = 254;
    static readonly RULE_stringOrParameter = 255;
    static readonly RULE_mapOrParameter = 256;
    static readonly RULE_map = 257;
    static readonly RULE_symbolicNamePositions = 258;
    static readonly RULE_symbolicNameString = 259;
    static readonly RULE_escapedSymbolicNameString = 260;
    static readonly RULE_unescapedSymbolicNameString = 261;
    static readonly RULE_symbolicLabelNameString = 262;
    static readonly RULE_unescapedLabelSymbolicNameString = 263;
    static readonly RULE_endOfFile = 264;
    static readonly literalNames: (string | null)[];
    static readonly symbolicNames: (string | null)[];
    static readonly ruleNames: string[];
    get grammarFileName(): string;
    get literalNames(): (string | null)[];
    get symbolicNames(): (string | null)[];
    get ruleNames(): string[];
    get serializedATN(): number[];
    protected createFailedPredicateException(predicate?: string, message?: string): FailedPredicateException;
    constructor(input: TokenStream);
    statements(): StatementsContext;
    statement(): StatementContext;
    preparserOption(): PreparserOptionContext;
    singleQueryOrCommand(): SingleQueryOrCommandContext;
    singleQueryOrCommandWithUseClause(): SingleQueryOrCommandWithUseClauseContext;
    periodicCommitQueryHintFailure(): PeriodicCommitQueryHintFailureContext;
    regularQuery(): RegularQueryContext;
    union(): UnionContext;
    singleQuery(): SingleQueryContext;
    singleQueryWithUseClause(): SingleQueryWithUseClauseContext;
    clause(): ClauseContext;
    useClause(): UseClauseContext;
    returnClause(): ReturnClauseContext;
    returnBody(): ReturnBodyContext;
    returnItem(): ReturnItemContext;
    returnItems(): ReturnItemsContext;
    orderItem(): OrderItemContext;
    skip(): SkipContext;
    limit(): LimitContext;
    whereClause(): WhereClauseContext;
    withClause(): WithClauseContext;
    createClause(): CreateClauseContext;
    setClause(): SetClauseContext;
    setItem(): SetItemContext;
    removeClause(): RemoveClauseContext;
    removeItem(): RemoveItemContext;
    deleteClause(): DeleteClauseContext;
    matchClause(): MatchClauseContext;
    matchMode(): MatchModeContext;
    hints(): HintsContext;
    indexHintBody(): IndexHintBodyContext;
    mergeClause(): MergeClauseContext;
    unwindClause(): UnwindClauseContext;
    callClause(): CallClauseContext;
    procedureName(): ProcedureNameContext;
    procedureArgument(): ProcedureArgumentContext;
    procedureResultItem(): ProcedureResultItemContext;
    loadCSVClause(): LoadCSVClauseContext;
    foreachClause(): ForeachClauseContext;
    subqueryClause(): SubqueryClauseContext;
    subqueryInTransactionsParameters(): SubqueryInTransactionsParametersContext;
    subqueryInTransactionsBatchParameters(): SubqueryInTransactionsBatchParametersContext;
    subqueryInTransactionsErrorParameters(): SubqueryInTransactionsErrorParametersContext;
    subqueryInTransactionsReportParameters(): SubqueryInTransactionsReportParametersContext;
    patternList(): PatternListContext;
    pattern(): PatternContext;
    quantifier(): QuantifierContext;
    anonymousPattern(): AnonymousPatternContext;
    shortestPathPattern(): ShortestPathPatternContext;
    maybeQuantifiedRelationshipPattern(): MaybeQuantifiedRelationshipPatternContext;
    patternElement(): PatternElementContext;
    pathPatternAtoms(): PathPatternAtomsContext;
    selector(): SelectorContext;
    pathPatternNonEmpty(): PathPatternNonEmptyContext;
    nodePattern(): NodePatternContext;
    parenthesizedPath(): ParenthesizedPathContext;
    nodeLabels(): NodeLabelsContext;
    labelExpressionPredicate(): LabelExpressionPredicateContext;
    labelOrRelType(): LabelOrRelTypeContext;
    labelOrRelTypes(): LabelOrRelTypesContext;
    properties(): PropertiesContext;
    relationshipPattern(): RelationshipPatternContext;
    leftArrow(): LeftArrowContext;
    arrowLine(): ArrowLineContext;
    rightArrow(): RightArrowContext;
    pathLength(): PathLengthContext;
    pathLengthLiteral(): PathLengthLiteralContext;
    labelExpression(): LabelExpressionContext;
    labelExpression4(): LabelExpression4Context;
    labelExpression4Is(): LabelExpression4IsContext;
    labelExpression3(): LabelExpression3Context;
    labelExpression3Is(): LabelExpression3IsContext;
    labelExpression2(): LabelExpression2Context;
    labelExpression2Is(): LabelExpression2IsContext;
    labelExpression1(): LabelExpression1Context;
    labelExpression1Is(): LabelExpression1IsContext;
    expression(): ExpressionContext;
    expression12(): Expression12Context;
    expression11(): Expression11Context;
    expression10(): Expression10Context;
    expression9(): Expression9Context;
    expression8(): Expression8Context;
    expression7(): Expression7Context;
    comparisonExpression6(): ComparisonExpression6Context;
    expression6(): Expression6Context;
    expression5(): Expression5Context;
    expression4(): Expression4Context;
    expression3(): Expression3Context;
    expression2(): Expression2Context;
    postFix1(): PostFix1Context;
    property(): PropertyContext;
    propertyExpression(): PropertyExpressionContext;
    expression1(): Expression1Context;
    literal(): LiteralContext;
    caseExpression(): CaseExpressionContext;
    listComprehension(): ListComprehensionContext;
    listComprehensionWhereAndBar(): ListComprehensionWhereAndBarContext;
    patternComprehension(): PatternComprehensionContext;
    reduceExpression(): ReduceExpressionContext;
    allExpression(): AllExpressionContext;
    anyExpression(): AnyExpressionContext;
    noneExpression(): NoneExpressionContext;
    singleExpression(): SingleExpressionContext;
    patternExpression(): PatternExpressionContext;
    shortestPathExpression(): ShortestPathExpressionContext;
    mapProjection(): MapProjectionContext;
    mapProjectionItem(): MapProjectionItemContext;
    existsExpression(): ExistsExpressionContext;
    countExpression(): CountExpressionContext;
    collectExpression(): CollectExpressionContext;
    stringLiteral(): StringLiteralContext;
    numberLiteral(): NumberLiteralContext;
    signedIntegerLiteral(): SignedIntegerLiteralContext;
    listLiteral(): ListLiteralContext;
    mapLiteral(): MapLiteralContext;
    propertyKeyName(): PropertyKeyNameContext;
    parameter(): ParameterContext;
    parameterName(): ParameterNameContext;
    functionInvocation(): FunctionInvocationContext;
    functionName(): FunctionNameContext;
    functionArgument(): FunctionArgumentContext;
    namespace(): NamespaceContext;
    variableList1(): VariableList1Context;
    variable(): VariableContext;
    symbolicNameList1(): SymbolicNameList1Context;
    createCommand(): CreateCommandContext;
    command(): CommandContext;
    commandWithUseGraph(): CommandWithUseGraphContext;
    dropCommand(): DropCommandContext;
    alterCommand(): AlterCommandContext;
    showCommand(): ShowCommandContext;
    terminateCommand(): TerminateCommandContext;
    showAllCommand(): ShowAllCommandContext;
    showNodeCommand(): ShowNodeCommandContext;
    showRelationshipCommand(): ShowRelationshipCommandContext;
    showRelCommand(): ShowRelCommandContext;
    showPropertyCommand(): ShowPropertyCommandContext;
    yieldItem(): YieldItemContext;
    yieldClause(): YieldClauseContext;
    showIndexesAllowBrief(): ShowIndexesAllowBriefContext;
    showIndexesNoBrief(): ShowIndexesNoBriefContext;
    showConstraintsAllowBriefAndYield(): ShowConstraintsAllowBriefAndYieldContext;
    showConstraintsAllowBrief(): ShowConstraintsAllowBriefContext;
    showConstraintsAllowYield(): ShowConstraintsAllowYieldContext;
    showProcedures(): ShowProceduresContext;
    showFunctions(): ShowFunctionsContext;
    showTransactions(): ShowTransactionsContext;
    terminateTransactions(): TerminateTransactionsContext;
    showOrTerminateTransactions(): ShowOrTerminateTransactionsContext;
    stringsOrExpression(): StringsOrExpressionContext;
    showSettings(): ShowSettingsContext;
    createConstraint(): CreateConstraintContext;
    cypherTypeName(): CypherTypeNameContext;
    cypherTypeNameList(): CypherTypeNameListContext;
    cypherTypeNamePart(): CypherTypeNamePartContext;
    constraintNodePattern(): ConstraintNodePatternContext;
    constraintRelPattern(): ConstraintRelPatternContext;
    createConstraintNodeCheck(): CreateConstraintNodeCheckContext;
    createConstraintRelCheck(): CreateConstraintRelCheckContext;
    dropConstraint(): DropConstraintContext;
    dropConstraintNodeCheck(): DropConstraintNodeCheckContext;
    createIndex(): CreateIndexContext;
    oldCreateIndex(): OldCreateIndexContext;
    createIndex_(): CreateIndex_Context;
    createFulltextIndex(): CreateFulltextIndexContext;
    createLookupIndex(): CreateLookupIndexContext;
    lookupIndexFunctionName(): LookupIndexFunctionNameContext;
    dropIndex(): DropIndexContext;
    propertyList(): PropertyListContext;
    renameCommand(): RenameCommandContext;
    grantCommand(): GrantCommandContext;
    revokeCommand(): RevokeCommandContext;
    enableServerCommand(): EnableServerCommandContext;
    alterServer(): AlterServerContext;
    renameServer(): RenameServerContext;
    dropServer(): DropServerContext;
    showServers(): ShowServersContext;
    allocationCommand(): AllocationCommandContext;
    deallocateDatabaseFromServers(): DeallocateDatabaseFromServersContext;
    reallocateDatabases(): ReallocateDatabasesContext;
    createRole(): CreateRoleContext;
    dropRole(): DropRoleContext;
    renameRole(): RenameRoleContext;
    showRoles(): ShowRolesContext;
    grantRole(): GrantRoleContext;
    revokeRole(): RevokeRoleContext;
    createUser(): CreateUserContext;
    dropUser(): DropUserContext;
    renameUser(): RenameUserContext;
    alterCurrentUser(): AlterCurrentUserContext;
    alterUser(): AlterUserContext;
    setPassword(): SetPasswordContext;
    passwordExpression(): PasswordExpressionContext;
    passwordChangeRequired(): PasswordChangeRequiredContext;
    userStatus(): UserStatusContext;
    homeDatabase(): HomeDatabaseContext;
    showUsers(): ShowUsersContext;
    showCurrentUser(): ShowCurrentUserContext;
    showSupportedPrivileges(): ShowSupportedPrivilegesContext;
    showPrivileges(): ShowPrivilegesContext;
    showRolePrivileges(): ShowRolePrivilegesContext;
    showUserPrivileges(): ShowUserPrivilegesContext;
    grantRoleManagement(): GrantRoleManagementContext;
    revokeRoleManagement(): RevokeRoleManagementContext;
    roleManagementPrivilege(): RoleManagementPrivilegeContext;
    grantPrivilege(): GrantPrivilegeContext;
    denyPrivilege(): DenyPrivilegeContext;
    revokePrivilege(): RevokePrivilegeContext;
    privilege(): PrivilegeContext;
    allPrivilege(): AllPrivilegeContext;
    allPrivilegeType(): AllPrivilegeTypeContext;
    allPrivilegeTarget(): AllPrivilegeTargetContext;
    createPrivilege(): CreatePrivilegeContext;
    dropPrivilege(): DropPrivilegeContext;
    loadPrivilege(): LoadPrivilegeContext;
    showPrivilege(): ShowPrivilegeContext;
    setPrivilege(): SetPrivilegeContext;
    removePrivilege(): RemovePrivilegeContext;
    writePrivilege(): WritePrivilegeContext;
    databasePrivilege(): DatabasePrivilegeContext;
    dbmsPrivilege(): DbmsPrivilegeContext;
    executeFunctionQualifier(): ExecuteFunctionQualifierContext;
    executeProcedureQualifier(): ExecuteProcedureQualifierContext;
    settingQualifier(): SettingQualifierContext;
    globs(): GlobsContext;
    qualifiedGraphPrivilegesWithProperty(): QualifiedGraphPrivilegesWithPropertyContext;
    qualifiedGraphPrivileges(): QualifiedGraphPrivilegesContext;
    labelResource(): LabelResourceContext;
    propertyResource(): PropertyResourceContext;
    graphQualifier(): GraphQualifierContext;
    createDatabase(): CreateDatabaseContext;
    options_(): Options_Context;
    createCompositeDatabase(): CreateCompositeDatabaseContext;
    dropDatabase(): DropDatabaseContext;
    alterDatabase(): AlterDatabaseContext;
    startDatabase(): StartDatabaseContext;
    stopDatabase(): StopDatabaseContext;
    waitClause(): WaitClauseContext;
    showDatabase(): ShowDatabaseContext;
    databaseScope(): DatabaseScopeContext;
    graphScope(): GraphScopeContext;
    createAlias(): CreateAliasContext;
    dropAlias(): DropAliasContext;
    alterAlias(): AlterAliasContext;
    showAliases(): ShowAliasesContext;
    symbolicAliasNameList(): SymbolicAliasNameListContext;
    symbolicAliasName(): SymbolicAliasNameContext;
    symbolicNameOrStringParameterList(): SymbolicNameOrStringParameterListContext;
    symbolicNameOrStringParameter(): SymbolicNameOrStringParameterContext;
    glob(): GlobContext;
    globRecursive(): GlobRecursiveContext;
    globPart(): GlobPartContext;
    stringImage(): StringImageContext;
    stringList(): StringListContext;
    stringToken(): StringTokenContext;
    stringOrParameter(): StringOrParameterContext;
    mapOrParameter(): MapOrParameterContext;
    map(): MapContext;
    symbolicNamePositions(): SymbolicNamePositionsContext;
    symbolicNameString(): SymbolicNameStringContext;
    escapedSymbolicNameString(): EscapedSymbolicNameStringContext;
    unescapedSymbolicNameString(): UnescapedSymbolicNameStringContext;
    symbolicLabelNameString(): SymbolicLabelNameStringContext;
    unescapedLabelSymbolicNameString(): UnescapedLabelSymbolicNameStringContext;
    endOfFile(): EndOfFileContext;
    static readonly _serializedATN: number[];
    private static __ATN;
    static get _ATN(): ATN;
    static DecisionsToDFA: DFA[];
}
export declare class StatementsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    statement_list(): StatementContext[];
    statement(i: number): StatementContext;
    EOF(): TerminalNode;
    SEMICOLON_list(): TerminalNode[];
    SEMICOLON(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class StatementContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    useClause(): UseClauseContext;
    singleQueryOrCommandWithUseClause(): SingleQueryOrCommandWithUseClauseContext;
    singleQueryOrCommand(): SingleQueryOrCommandContext;
    preparserOption(): PreparserOptionContext;
    periodicCommitQueryHintFailure(): PeriodicCommitQueryHintFailureContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PreparserOptionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    EXPLAIN(): TerminalNode;
    PROFILE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SingleQueryOrCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    createCommand(): CreateCommandContext;
    command(): CommandContext;
    singleQuery(): SingleQueryContext;
    union_list(): UnionContext[];
    union(i: number): UnionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SingleQueryOrCommandWithUseClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    createCommand(): CreateCommandContext;
    command(): CommandContext;
    singleQueryWithUseClause(): SingleQueryWithUseClauseContext;
    union_list(): UnionContext[];
    union(i: number): UnionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PeriodicCommitQueryHintFailureContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    USING(): TerminalNode;
    PERIODIC(): TerminalNode;
    COMMIT(): TerminalNode;
    UNSIGNED_DECIMAL_INTEGER(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RegularQueryContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    singleQuery(): SingleQueryContext;
    union_list(): UnionContext[];
    union(i: number): UnionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class UnionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    UNION(): TerminalNode;
    singleQuery(): SingleQueryContext;
    ALL(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SingleQueryContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    clause_list(): ClauseContext[];
    clause(i: number): ClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SingleQueryWithUseClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    clause_list(): ClauseContext[];
    clause(i: number): ClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    useClause(): UseClauseContext;
    returnClause(): ReturnClauseContext;
    createClause(): CreateClauseContext;
    deleteClause(): DeleteClauseContext;
    setClause(): SetClauseContext;
    removeClause(): RemoveClauseContext;
    matchClause(): MatchClauseContext;
    mergeClause(): MergeClauseContext;
    withClause(): WithClauseContext;
    unwindClause(): UnwindClauseContext;
    callClause(): CallClauseContext;
    subqueryClause(): SubqueryClauseContext;
    loadCSVClause(): LoadCSVClauseContext;
    foreachClause(): ForeachClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class UseClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    USE(): TerminalNode;
    GRAPH(): TerminalNode;
    expression(): ExpressionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ReturnClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    RETURN(): TerminalNode;
    returnBody(): ReturnBodyContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ReturnBodyContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    returnItems(): ReturnItemsContext;
    DISTINCT(): TerminalNode;
    ORDER(): TerminalNode;
    BY(): TerminalNode;
    orderItem_list(): OrderItemContext[];
    orderItem(i: number): OrderItemContext;
    skip(): SkipContext;
    limit(): LimitContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ReturnItemContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression(): ExpressionContext;
    AS(): TerminalNode;
    variable(): VariableContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ReturnItemsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    TIMES(): TerminalNode;
    returnItem_list(): ReturnItemContext[];
    returnItem(i: number): ReturnItemContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class OrderItemContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression(): ExpressionContext;
    DESC(): TerminalNode;
    ASC(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SkipContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    SKIPROWS(): TerminalNode;
    expression(): ExpressionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LimitContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    LIMITROWS(): TerminalNode;
    expression(): ExpressionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class WhereClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    WHERE(): TerminalNode;
    expression(): ExpressionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class WithClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    WITH(): TerminalNode;
    returnBody(): ReturnBodyContext;
    whereClause(): WhereClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CREATE(): TerminalNode;
    patternList(): PatternListContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SetClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    SET(): TerminalNode;
    setItem_list(): SetItemContext[];
    setItem(i: number): SetItemContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SetItemContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    propertyExpression(): PropertyExpressionContext;
    EQ(): TerminalNode;
    expression(): ExpressionContext;
    variable(): VariableContext;
    PLUSEQUAL(): TerminalNode;
    nodeLabels(): NodeLabelsContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RemoveClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    REMOVE(): TerminalNode;
    removeItem_list(): RemoveItemContext[];
    removeItem(i: number): RemoveItemContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RemoveItemContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    propertyExpression(): PropertyExpressionContext;
    variable(): VariableContext;
    nodeLabels(): NodeLabelsContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DeleteClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DELETE(): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    DETACH(): TerminalNode;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class MatchClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    MATCH(): TerminalNode;
    patternList(): PatternListContext;
    OPTIONAL(): TerminalNode;
    matchMode(): MatchModeContext;
    hints_list(): HintsContext[];
    hints(i: number): HintsContext;
    whereClause(): WhereClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class MatchModeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    REPEATABLE(): TerminalNode;
    ELEMENT(): TerminalNode;
    BINDINGS(): TerminalNode;
    ELEMENTS(): TerminalNode;
    DIFFERENT(): TerminalNode;
    RELATIONSHIP(): TerminalNode;
    RELATIONSHIPS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class HintsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    USING(): TerminalNode;
    INDEX(): TerminalNode;
    indexHintBody(): IndexHintBodyContext;
    BTREE(): TerminalNode;
    TEXT(): TerminalNode;
    RANGE(): TerminalNode;
    POINT(): TerminalNode;
    JOIN(): TerminalNode;
    ON(): TerminalNode;
    variableList1(): VariableList1Context;
    SCAN(): TerminalNode;
    variable(): VariableContext;
    labelOrRelType(): LabelOrRelTypeContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class IndexHintBodyContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    variable(): VariableContext;
    labelOrRelType(): LabelOrRelTypeContext;
    LPAREN(): TerminalNode;
    symbolicNameList1(): SymbolicNameList1Context;
    RPAREN(): TerminalNode;
    SEEK(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class MergeClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    MERGE(): TerminalNode;
    pattern(): PatternContext;
    ON_list(): TerminalNode[];
    ON(i: number): TerminalNode;
    MATCH_list(): TerminalNode[];
    MATCH(i: number): TerminalNode;
    setClause_list(): SetClauseContext[];
    setClause(i: number): SetClauseContext;
    CREATE_list(): TerminalNode[];
    CREATE(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class UnwindClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    UNWIND(): TerminalNode;
    expression(): ExpressionContext;
    AS(): TerminalNode;
    variable(): VariableContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CallClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CALL(): TerminalNode;
    procedureName(): ProcedureNameContext;
    LPAREN(): TerminalNode;
    RPAREN(): TerminalNode;
    YIELD(): TerminalNode;
    TIMES(): TerminalNode;
    procedureResultItem_list(): ProcedureResultItemContext[];
    procedureResultItem(i: number): ProcedureResultItemContext;
    procedureArgument_list(): ProcedureArgumentContext[];
    procedureArgument(i: number): ProcedureArgumentContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    whereClause(): WhereClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ProcedureNameContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    namespace(): NamespaceContext;
    symbolicNameString(): SymbolicNameStringContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ProcedureArgumentContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression(): ExpressionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ProcedureResultItemContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameString(): SymbolicNameStringContext;
    AS(): TerminalNode;
    variable(): VariableContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LoadCSVClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    LOAD(): TerminalNode;
    CSV(): TerminalNode;
    FROM(): TerminalNode;
    expression(): ExpressionContext;
    AS(): TerminalNode;
    variable(): VariableContext;
    WITH(): TerminalNode;
    HEADERS(): TerminalNode;
    FIELDTERMINATOR(): TerminalNode;
    stringToken(): StringTokenContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ForeachClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    FOREACH(): TerminalNode;
    LPAREN(): TerminalNode;
    variable(): VariableContext;
    IN(): TerminalNode;
    expression(): ExpressionContext;
    BAR(): TerminalNode;
    RPAREN(): TerminalNode;
    clause_list(): ClauseContext[];
    clause(i: number): ClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SubqueryClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CALL(): TerminalNode;
    LCURLY(): TerminalNode;
    regularQuery(): RegularQueryContext;
    RCURLY(): TerminalNode;
    subqueryInTransactionsParameters(): SubqueryInTransactionsParametersContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SubqueryInTransactionsParametersContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    IN(): TerminalNode;
    TRANSACTIONS(): TerminalNode;
    subqueryInTransactionsBatchParameters_list(): SubqueryInTransactionsBatchParametersContext[];
    subqueryInTransactionsBatchParameters(i: number): SubqueryInTransactionsBatchParametersContext;
    subqueryInTransactionsErrorParameters_list(): SubqueryInTransactionsErrorParametersContext[];
    subqueryInTransactionsErrorParameters(i: number): SubqueryInTransactionsErrorParametersContext;
    subqueryInTransactionsReportParameters_list(): SubqueryInTransactionsReportParametersContext[];
    subqueryInTransactionsReportParameters(i: number): SubqueryInTransactionsReportParametersContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SubqueryInTransactionsBatchParametersContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    OF(): TerminalNode;
    expression(): ExpressionContext;
    ROW(): TerminalNode;
    ROWS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SubqueryInTransactionsErrorParametersContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ON(): TerminalNode;
    ERROR(): TerminalNode;
    CONTINUE(): TerminalNode;
    BREAK(): TerminalNode;
    FAIL(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SubqueryInTransactionsReportParametersContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    REPORT(): TerminalNode;
    STATUS(): TerminalNode;
    AS(): TerminalNode;
    variable(): VariableContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PatternListContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    pattern_list(): PatternContext[];
    pattern(i: number): PatternContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PatternContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    anonymousPattern(): AnonymousPatternContext;
    variable(): VariableContext;
    EQ(): TerminalNode;
    selector(): SelectorContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class QuantifierContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    LCURLY(): TerminalNode;
    UNSIGNED_DECIMAL_INTEGER_list(): TerminalNode[];
    UNSIGNED_DECIMAL_INTEGER(i: number): TerminalNode;
    RCURLY(): TerminalNode;
    COMMA(): TerminalNode;
    PLUS(): TerminalNode;
    TIMES(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AnonymousPatternContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    shortestPathPattern(): ShortestPathPatternContext;
    patternElement(): PatternElementContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShortestPathPatternContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    SHORTEST_PATH(): TerminalNode;
    LPAREN(): TerminalNode;
    patternElement(): PatternElementContext;
    RPAREN(): TerminalNode;
    ALL_SHORTEST_PATH(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class MaybeQuantifiedRelationshipPatternContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    relationshipPattern(): RelationshipPatternContext;
    quantifier(): QuantifierContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PatternElementContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    pathPatternAtoms(): PathPatternAtomsContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PathPatternAtomsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    nodePattern_list(): NodePatternContext[];
    nodePattern(i: number): NodePatternContext;
    parenthesizedPath_list(): ParenthesizedPathContext[];
    parenthesizedPath(i: number): ParenthesizedPathContext;
    maybeQuantifiedRelationshipPattern_list(): MaybeQuantifiedRelationshipPatternContext[];
    maybeQuantifiedRelationshipPattern(i: number): MaybeQuantifiedRelationshipPatternContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SelectorContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ANY(): TerminalNode;
    SHORTEST(): TerminalNode;
    ALL(): TerminalNode;
    UNSIGNED_DECIMAL_INTEGER(): TerminalNode;
    GROUP(): TerminalNode;
    GROUPS(): TerminalNode;
    PATH(): TerminalNode;
    PATHS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PathPatternNonEmptyContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    nodePattern_list(): NodePatternContext[];
    nodePattern(i: number): NodePatternContext;
    relationshipPattern_list(): RelationshipPatternContext[];
    relationshipPattern(i: number): RelationshipPatternContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class NodePatternContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    LPAREN(): TerminalNode;
    RPAREN(): TerminalNode;
    variable(): VariableContext;
    labelExpression(): LabelExpressionContext;
    properties(): PropertiesContext;
    WHERE(): TerminalNode;
    expression(): ExpressionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ParenthesizedPathContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    LPAREN(): TerminalNode;
    pattern(): PatternContext;
    RPAREN(): TerminalNode;
    WHERE(): TerminalNode;
    expression(): ExpressionContext;
    quantifier(): QuantifierContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class NodeLabelsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    labelOrRelType_list(): LabelOrRelTypeContext[];
    labelOrRelType(i: number): LabelOrRelTypeContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelExpressionPredicateContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    labelExpression(): LabelExpressionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelOrRelTypeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    COLON(): TerminalNode;
    symbolicNameString(): SymbolicNameStringContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelOrRelTypesContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    COLON(): TerminalNode;
    symbolicNameString_list(): SymbolicNameStringContext[];
    symbolicNameString(i: number): SymbolicNameStringContext;
    BAR_list(): TerminalNode[];
    BAR(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PropertiesContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    mapLiteral(): MapLiteralContext;
    parameter(): ParameterContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RelationshipPatternContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    arrowLine_list(): ArrowLineContext[];
    arrowLine(i: number): ArrowLineContext;
    leftArrow(): LeftArrowContext;
    LBRACKET(): TerminalNode;
    RBRACKET(): TerminalNode;
    rightArrow(): RightArrowContext;
    variable(): VariableContext;
    labelExpression(): LabelExpressionContext;
    pathLength(): PathLengthContext;
    properties(): PropertiesContext;
    WHERE(): TerminalNode;
    expression(): ExpressionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LeftArrowContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    LT(): TerminalNode;
    ARROW_LEFT_HEAD(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ArrowLineContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ARROW_LINE(): TerminalNode;
    MINUS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RightArrowContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    GT(): TerminalNode;
    ARROW_RIGHT_HEAD(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PathLengthContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    TIMES(): TerminalNode;
    pathLengthLiteral(): PathLengthLiteralContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PathLengthLiteralContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DOTDOT(): TerminalNode;
    UNSIGNED_DECIMAL_INTEGER_list(): TerminalNode[];
    UNSIGNED_DECIMAL_INTEGER(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    COLON(): TerminalNode;
    labelExpression4(): LabelExpression4Context;
    IS(): TerminalNode;
    labelExpression4Is(): LabelExpression4IsContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelExpression4Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    labelExpression3_list(): LabelExpression3Context[];
    labelExpression3(i: number): LabelExpression3Context;
    BAR_list(): TerminalNode[];
    BAR(i: number): TerminalNode;
    COLON_list(): TerminalNode[];
    COLON(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelExpression4IsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    labelExpression3Is_list(): LabelExpression3IsContext[];
    labelExpression3Is(i: number): LabelExpression3IsContext;
    BAR_list(): TerminalNode[];
    BAR(i: number): TerminalNode;
    COLON_list(): TerminalNode[];
    COLON(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelExpression3Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    labelExpression2_list(): LabelExpression2Context[];
    labelExpression2(i: number): LabelExpression2Context;
    AMPERSAND_list(): TerminalNode[];
    AMPERSAND(i: number): TerminalNode;
    COLON_list(): TerminalNode[];
    COLON(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelExpression3IsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    labelExpression2Is_list(): LabelExpression2IsContext[];
    labelExpression2Is(i: number): LabelExpression2IsContext;
    AMPERSAND_list(): TerminalNode[];
    AMPERSAND(i: number): TerminalNode;
    COLON_list(): TerminalNode[];
    COLON(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelExpression2Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    EXCLAMATION_MARK(): TerminalNode;
    labelExpression2(): LabelExpression2Context;
    labelExpression1(): LabelExpression1Context;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelExpression2IsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    EXCLAMATION_MARK(): TerminalNode;
    labelExpression2Is(): LabelExpression2IsContext;
    labelExpression1Is(): LabelExpression1IsContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelExpression1Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    get ruleIndex(): number;
    copyFrom(ctx: LabelExpression1Context): void;
}
export declare class AnyLabelContext extends LabelExpression1Context {
    constructor(parser: CypherParser, ctx: LabelExpression1Context);
    PERCENT(): TerminalNode;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelNameContext extends LabelExpression1Context {
    constructor(parser: CypherParser, ctx: LabelExpression1Context);
    symbolicNameString(): SymbolicNameStringContext;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ParenthesizedLabelExpressionContext extends LabelExpression1Context {
    constructor(parser: CypherParser, ctx: LabelExpression1Context);
    LPAREN(): TerminalNode;
    labelExpression4(): LabelExpression4Context;
    RPAREN(): TerminalNode;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelExpression1IsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    get ruleIndex(): number;
    copyFrom(ctx: LabelExpression1IsContext): void;
}
export declare class ParenthesizedLabelExpressionIsContext extends LabelExpression1IsContext {
    constructor(parser: CypherParser, ctx: LabelExpression1IsContext);
    LPAREN(): TerminalNode;
    labelExpression4Is(): LabelExpression4IsContext;
    RPAREN(): TerminalNode;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AnyLabelIsContext extends LabelExpression1IsContext {
    constructor(parser: CypherParser, ctx: LabelExpression1IsContext);
    PERCENT(): TerminalNode;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelNameIsContext extends LabelExpression1IsContext {
    constructor(parser: CypherParser, ctx: LabelExpression1IsContext);
    symbolicLabelNameString(): SymbolicLabelNameStringContext;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression12(): Expression12Context;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class Expression12Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression11_list(): Expression11Context[];
    expression11(i: number): Expression11Context;
    OR_list(): TerminalNode[];
    OR(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class Expression11Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression10_list(): Expression10Context[];
    expression10(i: number): Expression10Context;
    XOR_list(): TerminalNode[];
    XOR(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class Expression10Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression9_list(): Expression9Context[];
    expression9(i: number): Expression9Context;
    AND_list(): TerminalNode[];
    AND(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class Expression9Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    NOT(): TerminalNode;
    expression9(): Expression9Context;
    expression8(): Expression8Context;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class Expression8Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression7_list(): Expression7Context[];
    expression7(i: number): Expression7Context;
    EQ_list(): TerminalNode[];
    EQ(i: number): TerminalNode;
    NEQ_list(): TerminalNode[];
    NEQ(i: number): TerminalNode;
    NEQ2_list(): TerminalNode[];
    NEQ2(i: number): TerminalNode;
    LE_list(): TerminalNode[];
    LE(i: number): TerminalNode;
    GE_list(): TerminalNode[];
    GE(i: number): TerminalNode;
    LT_list(): TerminalNode[];
    LT(i: number): TerminalNode;
    GT_list(): TerminalNode[];
    GT(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class Expression7Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression6(): Expression6Context;
    comparisonExpression6(): ComparisonExpression6Context;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ComparisonExpression6Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    REGEQ(): TerminalNode;
    expression6(): Expression6Context;
    STARTS(): TerminalNode;
    WITH(): TerminalNode;
    ENDS(): TerminalNode;
    CONTAINS(): TerminalNode;
    IN(): TerminalNode;
    IS(): TerminalNode;
    COLONCOLON(): TerminalNode;
    cypherTypeName(): CypherTypeNameContext;
    NULL(): TerminalNode;
    NOT(): TerminalNode;
    TYPED(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class Expression6Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression5_list(): Expression5Context[];
    expression5(i: number): Expression5Context;
    PLUS_list(): TerminalNode[];
    PLUS(i: number): TerminalNode;
    MINUS_list(): TerminalNode[];
    MINUS(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class Expression5Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression4_list(): Expression4Context[];
    expression4(i: number): Expression4Context;
    TIMES_list(): TerminalNode[];
    TIMES(i: number): TerminalNode;
    DIVIDE_list(): TerminalNode[];
    DIVIDE(i: number): TerminalNode;
    PERCENT_list(): TerminalNode[];
    PERCENT(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class Expression4Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression3_list(): Expression3Context[];
    expression3(i: number): Expression3Context;
    POW_list(): TerminalNode[];
    POW(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class Expression3Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression2(): Expression2Context;
    PLUS(): TerminalNode;
    MINUS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class Expression2Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression1(): Expression1Context;
    postFix1_list(): PostFix1Context[];
    postFix1(i: number): PostFix1Context;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PostFix1Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    property(): PropertyContext;
    labelExpressionPredicate(): LabelExpressionPredicateContext;
    LBRACKET(): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    RBRACKET(): TerminalNode;
    DOTDOT(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PropertyContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DOT(): TerminalNode;
    propertyKeyName(): PropertyKeyNameContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PropertyExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression1(): Expression1Context;
    property_list(): PropertyContext[];
    property(i: number): PropertyContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class Expression1Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    literal(): LiteralContext;
    parameter(): ParameterContext;
    caseExpression(): CaseExpressionContext;
    COUNT(): TerminalNode;
    LPAREN(): TerminalNode;
    TIMES(): TerminalNode;
    RPAREN(): TerminalNode;
    existsExpression(): ExistsExpressionContext;
    countExpression(): CountExpressionContext;
    collectExpression(): CollectExpressionContext;
    mapProjection(): MapProjectionContext;
    listComprehension(): ListComprehensionContext;
    patternComprehension(): PatternComprehensionContext;
    reduceExpression(): ReduceExpressionContext;
    allExpression(): AllExpressionContext;
    anyExpression(): AnyExpressionContext;
    noneExpression(): NoneExpressionContext;
    singleExpression(): SingleExpressionContext;
    patternExpression(): PatternExpressionContext;
    shortestPathExpression(): ShortestPathExpressionContext;
    expression(): ExpressionContext;
    functionInvocation(): FunctionInvocationContext;
    variable(): VariableContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LiteralContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    get ruleIndex(): number;
    copyFrom(ctx: LiteralContext): void;
}
export declare class NummericLiteralContext extends LiteralContext {
    constructor(parser: CypherParser, ctx: LiteralContext);
    numberLiteral(): NumberLiteralContext;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class BooleanLiteralContext extends LiteralContext {
    constructor(parser: CypherParser, ctx: LiteralContext);
    TRUE(): TerminalNode;
    FALSE(): TerminalNode;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class KeywordLiteralContext extends LiteralContext {
    constructor(parser: CypherParser, ctx: LiteralContext);
    INFINITY(): TerminalNode;
    INF(): TerminalNode;
    NAN(): TerminalNode;
    NULL(): TerminalNode;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class OtherLiteralContext extends LiteralContext {
    constructor(parser: CypherParser, ctx: LiteralContext);
    mapLiteral(): MapLiteralContext;
    listLiteral(): ListLiteralContext;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class StringsLiteralContext extends LiteralContext {
    constructor(parser: CypherParser, ctx: LiteralContext);
    stringLiteral(): StringLiteralContext;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CaseExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CASE(): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    THEN_list(): TerminalNode[];
    THEN(i: number): TerminalNode;
    END(): TerminalNode;
    WHEN_list(): TerminalNode[];
    WHEN(i: number): TerminalNode;
    ELSE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ListComprehensionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    LBRACKET(): TerminalNode;
    variable(): VariableContext;
    IN(): TerminalNode;
    expression(): ExpressionContext;
    listComprehensionWhereAndBar(): ListComprehensionWhereAndBarContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ListComprehensionWhereAndBarContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    BAR(): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    RBRACKET(): TerminalNode;
    WHERE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PatternComprehensionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    LBRACKET(): TerminalNode;
    pathPatternNonEmpty(): PathPatternNonEmptyContext;
    BAR(): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    RBRACKET(): TerminalNode;
    variable(): VariableContext;
    EQ(): TerminalNode;
    WHERE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ReduceExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    REDUCE(): TerminalNode;
    LPAREN(): TerminalNode;
    variable_list(): VariableContext[];
    variable(i: number): VariableContext;
    EQ(): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    COMMA(): TerminalNode;
    IN(): TerminalNode;
    BAR(): TerminalNode;
    RPAREN(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AllExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ALL(): TerminalNode;
    LPAREN(): TerminalNode;
    variable(): VariableContext;
    IN(): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    RPAREN(): TerminalNode;
    WHERE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AnyExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ANY(): TerminalNode;
    LPAREN(): TerminalNode;
    variable(): VariableContext;
    IN(): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    RPAREN(): TerminalNode;
    WHERE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class NoneExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    NONE(): TerminalNode;
    LPAREN(): TerminalNode;
    variable(): VariableContext;
    IN(): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    RPAREN(): TerminalNode;
    WHERE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SingleExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    SINGLE(): TerminalNode;
    LPAREN(): TerminalNode;
    variable(): VariableContext;
    IN(): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    RPAREN(): TerminalNode;
    WHERE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PatternExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    pathPatternNonEmpty(): PathPatternNonEmptyContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShortestPathExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    shortestPathPattern(): ShortestPathPatternContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class MapProjectionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    variable(): VariableContext;
    LCURLY(): TerminalNode;
    RCURLY(): TerminalNode;
    mapProjectionItem_list(): MapProjectionItemContext[];
    mapProjectionItem(i: number): MapProjectionItemContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class MapProjectionItemContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    propertyKeyName(): PropertyKeyNameContext;
    COLON(): TerminalNode;
    expression(): ExpressionContext;
    DOT(): TerminalNode;
    variable(): VariableContext;
    TIMES(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ExistsExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    EXISTS(): TerminalNode;
    LCURLY(): TerminalNode;
    RCURLY(): TerminalNode;
    regularQuery(): RegularQueryContext;
    patternList(): PatternListContext;
    matchMode(): MatchModeContext;
    whereClause(): WhereClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CountExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    COUNT(): TerminalNode;
    LCURLY(): TerminalNode;
    RCURLY(): TerminalNode;
    regularQuery(): RegularQueryContext;
    patternList(): PatternListContext;
    matchMode(): MatchModeContext;
    whereClause(): WhereClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CollectExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    COLLECT(): TerminalNode;
    LCURLY(): TerminalNode;
    regularQuery(): RegularQueryContext;
    RCURLY(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class StringLiteralContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    stringToken(): StringTokenContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class NumberLiteralContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DECIMAL_DOUBLE(): TerminalNode;
    UNSIGNED_DECIMAL_INTEGER(): TerminalNode;
    UNSIGNED_HEX_INTEGER(): TerminalNode;
    UNSIGNED_OCTAL_INTEGER(): TerminalNode;
    MINUS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SignedIntegerLiteralContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    UNSIGNED_DECIMAL_INTEGER(): TerminalNode;
    MINUS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ListLiteralContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    LBRACKET(): TerminalNode;
    RBRACKET(): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class MapLiteralContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    LCURLY(): TerminalNode;
    RCURLY(): TerminalNode;
    propertyKeyName_list(): PropertyKeyNameContext[];
    propertyKeyName(i: number): PropertyKeyNameContext;
    COLON_list(): TerminalNode[];
    COLON(i: number): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PropertyKeyNameContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameString(): SymbolicNameStringContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ParameterContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DOLLAR(): TerminalNode;
    parameterName(): ParameterNameContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ParameterNameContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    variable(): VariableContext;
    UNSIGNED_DECIMAL_INTEGER(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class FunctionInvocationContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    functionName(): FunctionNameContext;
    LPAREN(): TerminalNode;
    RPAREN(): TerminalNode;
    DISTINCT(): TerminalNode;
    functionArgument_list(): FunctionArgumentContext[];
    functionArgument(i: number): FunctionArgumentContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class FunctionNameContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    namespace(): NamespaceContext;
    symbolicNameString(): SymbolicNameStringContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class FunctionArgumentContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    expression(): ExpressionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class NamespaceContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameString_list(): SymbolicNameStringContext[];
    symbolicNameString(i: number): SymbolicNameStringContext;
    DOT_list(): TerminalNode[];
    DOT(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class VariableList1Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameString_list(): SymbolicNameStringContext[];
    symbolicNameString(i: number): SymbolicNameStringContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class VariableContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameString(): SymbolicNameStringContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SymbolicNameList1Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameString_list(): SymbolicNameStringContext[];
    symbolicNameString(i: number): SymbolicNameStringContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CREATE(): TerminalNode;
    createRole(): CreateRoleContext;
    createUser(): CreateUserContext;
    createDatabase(): CreateDatabaseContext;
    createConstraint(): CreateConstraintContext;
    createIndex(): CreateIndexContext;
    createAlias(): CreateAliasContext;
    createCompositeDatabase(): CreateCompositeDatabaseContext;
    OR(): TerminalNode;
    REPLACE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    commandWithUseGraph(): CommandWithUseGraphContext;
    showCommand(): ShowCommandContext;
    terminateCommand(): TerminateCommandContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CommandWithUseGraphContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    dropCommand(): DropCommandContext;
    alterCommand(): AlterCommandContext;
    renameCommand(): RenameCommandContext;
    denyPrivilege(): DenyPrivilegeContext;
    revokeCommand(): RevokeCommandContext;
    grantCommand(): GrantCommandContext;
    startDatabase(): StartDatabaseContext;
    stopDatabase(): StopDatabaseContext;
    enableServerCommand(): EnableServerCommandContext;
    allocationCommand(): AllocationCommandContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DropCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DROP(): TerminalNode;
    dropRole(): DropRoleContext;
    dropUser(): DropUserContext;
    dropDatabase(): DropDatabaseContext;
    dropConstraint(): DropConstraintContext;
    dropIndex(): DropIndexContext;
    dropAlias(): DropAliasContext;
    dropServer(): DropServerContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AlterCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ALTER(): TerminalNode;
    alterDatabase(): AlterDatabaseContext;
    alterAlias(): AlterAliasContext;
    alterCurrentUser(): AlterCurrentUserContext;
    alterUser(): AlterUserContext;
    alterServer(): AlterServerContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    SHOW(): TerminalNode;
    ALL(): TerminalNode;
    showAllCommand(): ShowAllCommandContext;
    POPULATED(): TerminalNode;
    showRoles(): ShowRolesContext;
    BTREE(): TerminalNode;
    showIndexesAllowBrief(): ShowIndexesAllowBriefContext;
    RANGE(): TerminalNode;
    showIndexesNoBrief(): ShowIndexesNoBriefContext;
    FULLTEXT(): TerminalNode;
    TEXT(): TerminalNode;
    POINT(): TerminalNode;
    LOOKUP(): TerminalNode;
    UNIQUE(): TerminalNode;
    showConstraintsAllowBriefAndYield(): ShowConstraintsAllowBriefAndYieldContext;
    UNIQUENESS(): TerminalNode;
    showConstraintsAllowYield(): ShowConstraintsAllowYieldContext;
    KEY(): TerminalNode;
    NODE(): TerminalNode;
    showNodeCommand(): ShowNodeCommandContext;
    PROPERTY(): TerminalNode;
    showPropertyCommand(): ShowPropertyCommandContext;
    EXISTENCE(): TerminalNode;
    EXISTS(): TerminalNode;
    showConstraintsAllowBrief(): ShowConstraintsAllowBriefContext;
    EXIST(): TerminalNode;
    RELATIONSHIP(): TerminalNode;
    showRelationshipCommand(): ShowRelationshipCommandContext;
    REL(): TerminalNode;
    showRelCommand(): ShowRelCommandContext;
    BUILT(): TerminalNode;
    IN(): TerminalNode;
    showFunctions(): ShowFunctionsContext;
    showDatabase(): ShowDatabaseContext;
    showCurrentUser(): ShowCurrentUserContext;
    showProcedures(): ShowProceduresContext;
    showSettings(): ShowSettingsContext;
    showTransactions(): ShowTransactionsContext;
    showAliases(): ShowAliasesContext;
    showServers(): ShowServersContext;
    showPrivileges(): ShowPrivilegesContext;
    showSupportedPrivileges(): ShowSupportedPrivilegesContext;
    USER(): TerminalNode;
    DEFINED(): TerminalNode;
    ROLES(): TerminalNode;
    ROLE(): TerminalNode;
    USERS(): TerminalNode;
    showRolePrivileges(): ShowRolePrivilegesContext;
    showUserPrivileges(): ShowUserPrivilegesContext;
    showUsers(): ShowUsersContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class TerminateCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    TERMINATE(): TerminalNode;
    terminateTransactions(): TerminateTransactionsContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowAllCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    showRoles(): ShowRolesContext;
    showIndexesAllowBrief(): ShowIndexesAllowBriefContext;
    showConstraintsAllowBriefAndYield(): ShowConstraintsAllowBriefAndYieldContext;
    showFunctions(): ShowFunctionsContext;
    showPrivileges(): ShowPrivilegesContext;
    ROLES(): TerminalNode;
    ROLE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowNodeCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    showConstraintsAllowYield(): ShowConstraintsAllowYieldContext;
    KEY(): TerminalNode;
    showConstraintsAllowBriefAndYield(): ShowConstraintsAllowBriefAndYieldContext;
    PROPERTY(): TerminalNode;
    showPropertyCommand(): ShowPropertyCommandContext;
    EXISTENCE(): TerminalNode;
    EXISTS(): TerminalNode;
    showConstraintsAllowBrief(): ShowConstraintsAllowBriefContext;
    EXIST(): TerminalNode;
    UNIQUE(): TerminalNode;
    UNIQUENESS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowRelationshipCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    showConstraintsAllowYield(): ShowConstraintsAllowYieldContext;
    KEY(): TerminalNode;
    PROPERTY(): TerminalNode;
    showPropertyCommand(): ShowPropertyCommandContext;
    EXISTENCE(): TerminalNode;
    EXISTS(): TerminalNode;
    showConstraintsAllowBrief(): ShowConstraintsAllowBriefContext;
    EXIST(): TerminalNode;
    showConstraintsAllowBriefAndYield(): ShowConstraintsAllowBriefAndYieldContext;
    UNIQUE(): TerminalNode;
    UNIQUENESS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowRelCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    showConstraintsAllowYield(): ShowConstraintsAllowYieldContext;
    KEY(): TerminalNode;
    PROPERTY(): TerminalNode;
    showPropertyCommand(): ShowPropertyCommandContext;
    EXISTENCE(): TerminalNode;
    EXIST(): TerminalNode;
    UNIQUE(): TerminalNode;
    UNIQUENESS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowPropertyCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    showConstraintsAllowYield(): ShowConstraintsAllowYieldContext;
    TYPE(): TerminalNode;
    EXISTENCE(): TerminalNode;
    EXIST(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class YieldItemContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    variable_list(): VariableContext[];
    variable(i: number): VariableContext;
    AS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class YieldClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    YIELD(): TerminalNode;
    TIMES(): TerminalNode;
    yieldItem_list(): YieldItemContext[];
    yieldItem(i: number): YieldItemContext;
    ORDER(): TerminalNode;
    BY(): TerminalNode;
    orderItem_list(): OrderItemContext[];
    orderItem(i: number): OrderItemContext;
    SKIPROWS(): TerminalNode;
    signedIntegerLiteral_list(): SignedIntegerLiteralContext[];
    signedIntegerLiteral(i: number): SignedIntegerLiteralContext;
    LIMITROWS(): TerminalNode;
    whereClause(): WhereClauseContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowIndexesAllowBriefContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    INDEX(): TerminalNode;
    INDEXES(): TerminalNode;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    BRIEF(): TerminalNode;
    VERBOSE(): TerminalNode;
    OUTPUT(): TerminalNode;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowIndexesNoBriefContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    INDEX(): TerminalNode;
    INDEXES(): TerminalNode;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowConstraintsAllowBriefAndYieldContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CONSTRAINT(): TerminalNode;
    CONSTRAINTS(): TerminalNode;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    BRIEF(): TerminalNode;
    VERBOSE(): TerminalNode;
    OUTPUT(): TerminalNode;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowConstraintsAllowBriefContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CONSTRAINT(): TerminalNode;
    CONSTRAINTS(): TerminalNode;
    BRIEF(): TerminalNode;
    VERBOSE(): TerminalNode;
    OUTPUT(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowConstraintsAllowYieldContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CONSTRAINT(): TerminalNode;
    CONSTRAINTS(): TerminalNode;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowProceduresContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    PROCEDURE(): TerminalNode;
    PROCEDURES(): TerminalNode;
    EXECUTABLE(): TerminalNode;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    BY(): TerminalNode;
    returnClause(): ReturnClauseContext;
    CURRENT(): TerminalNode;
    USER(): TerminalNode;
    symbolicNameString(): SymbolicNameStringContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowFunctionsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    FUNCTION(): TerminalNode;
    FUNCTIONS(): TerminalNode;
    EXECUTABLE(): TerminalNode;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    BY(): TerminalNode;
    returnClause(): ReturnClauseContext;
    CURRENT(): TerminalNode;
    USER(): TerminalNode;
    symbolicNameString(): SymbolicNameStringContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowTransactionsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    TRANSACTION(): TerminalNode;
    TRANSACTIONS(): TerminalNode;
    showOrTerminateTransactions(): ShowOrTerminateTransactionsContext;
    stringsOrExpression(): StringsOrExpressionContext;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class TerminateTransactionsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    TRANSACTION(): TerminalNode;
    TRANSACTIONS(): TerminalNode;
    showOrTerminateTransactions(): ShowOrTerminateTransactionsContext;
    stringsOrExpression(): StringsOrExpressionContext;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowOrTerminateTransactionsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    TERMINATE(): TerminalNode;
    terminateTransactions(): TerminateTransactionsContext;
    SHOW(): TerminalNode;
    showTransactions(): ShowTransactionsContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class StringsOrExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    stringList(): StringListContext;
    expression(): ExpressionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowSettingsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    SETTING(): TerminalNode;
    SETTINGS(): TerminalNode;
    stringsOrExpression(): StringsOrExpressionContext;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateConstraintContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CONSTRAINT(): TerminalNode;
    ON(): TerminalNode;
    LPAREN(): TerminalNode;
    FOR(): TerminalNode;
    IF(): TerminalNode;
    NOT_list(): TerminalNode[];
    NOT(i: number): TerminalNode;
    EXISTS_list(): TerminalNode[];
    EXISTS(i: number): TerminalNode;
    constraintNodePattern(): ConstraintNodePatternContext;
    constraintRelPattern(): ConstraintRelPatternContext;
    ASSERT(): TerminalNode;
    propertyList(): PropertyListContext;
    REQUIRE(): TerminalNode;
    OPTIONS(): TerminalNode;
    mapOrParameter(): MapOrParameterContext;
    COLONCOLON(): TerminalNode;
    cypherTypeName(): CypherTypeNameContext;
    IS(): TerminalNode;
    symbolicNameString(): SymbolicNameStringContext;
    UNIQUE(): TerminalNode;
    KEY(): TerminalNode;
    createConstraintNodeCheck(): CreateConstraintNodeCheckContext;
    createConstraintRelCheck(): CreateConstraintRelCheckContext;
    NULL(): TerminalNode;
    TYPED(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CypherTypeNameContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    cypherTypeNameList(): CypherTypeNameListContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CypherTypeNameListContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    cypherTypeNamePart_list(): CypherTypeNamePartContext[];
    cypherTypeNamePart(i: number): CypherTypeNamePartContext;
    BAR_list(): TerminalNode[];
    BAR(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CypherTypeNamePartContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    NOTHING(): TerminalNode;
    NULL_list(): TerminalNode[];
    NULL(i: number): TerminalNode;
    FLOAT(): TerminalNode;
    DATE(): TerminalNode;
    LOCAL(): TerminalNode;
    ZONED(): TerminalNode;
    TIME(): TerminalNode;
    TIMESTAMP(): TerminalNode;
    DURATION(): TerminalNode;
    POINT(): TerminalNode;
    MAP(): TerminalNode;
    LT(): TerminalNode;
    cypherTypeName(): CypherTypeNameContext;
    GT(): TerminalNode;
    PATH(): TerminalNode;
    PROPERTY(): TerminalNode;
    VALUE(): TerminalNode;
    ANY(): TerminalNode;
    BOOLEAN(): TerminalNode;
    BOOL(): TerminalNode;
    STRING(): TerminalNode;
    VARCHAR(): TerminalNode;
    DATETIME(): TerminalNode;
    NODE(): TerminalNode;
    VERTEX(): TerminalNode;
    RELATIONSHIP(): TerminalNode;
    EDGE(): TerminalNode;
    LIST_list(): TerminalNode[];
    LIST(i: number): TerminalNode;
    ARRAY_list(): TerminalNode[];
    ARRAY(i: number): TerminalNode;
    NOT_list(): TerminalNode[];
    NOT(i: number): TerminalNode;
    INT(): TerminalNode;
    INTEGER(): TerminalNode;
    WITHOUT(): TerminalNode;
    TIMEZONE(): TerminalNode;
    WITH(): TerminalNode;
    cypherTypeNameList(): CypherTypeNameListContext;
    SIGNED(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ConstraintNodePatternContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    variable(): VariableContext;
    labelOrRelType(): LabelOrRelTypeContext;
    RPAREN(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ConstraintRelPatternContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    RPAREN_list(): TerminalNode[];
    RPAREN(i: number): TerminalNode;
    arrowLine_list(): ArrowLineContext[];
    arrowLine(i: number): ArrowLineContext;
    LBRACKET(): TerminalNode;
    variable(): VariableContext;
    labelOrRelType(): LabelOrRelTypeContext;
    RBRACKET(): TerminalNode;
    LPAREN(): TerminalNode;
    leftArrow(): LeftArrowContext;
    rightArrow(): RightArrowContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateConstraintNodeCheckContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    NODE(): TerminalNode;
    KEY(): TerminalNode;
    UNIQUE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateConstraintRelCheckContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    RELATIONSHIP(): TerminalNode;
    REL(): TerminalNode;
    KEY(): TerminalNode;
    UNIQUE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DropConstraintContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CONSTRAINT(): TerminalNode;
    ON(): TerminalNode;
    LPAREN(): TerminalNode;
    ASSERT(): TerminalNode;
    symbolicNameString(): SymbolicNameStringContext;
    constraintNodePattern(): ConstraintNodePatternContext;
    constraintRelPattern(): ConstraintRelPatternContext;
    EXISTS(): TerminalNode;
    propertyList(): PropertyListContext;
    IS(): TerminalNode;
    IF(): TerminalNode;
    dropConstraintNodeCheck(): DropConstraintNodeCheckContext;
    NOT(): TerminalNode;
    NULL(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DropConstraintNodeCheckContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    UNIQUE(): TerminalNode;
    NODE(): TerminalNode;
    KEY(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateIndexContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    BTREE(): TerminalNode;
    INDEX(): TerminalNode;
    createIndex_(): CreateIndex_Context;
    RANGE(): TerminalNode;
    FULLTEXT(): TerminalNode;
    createFulltextIndex(): CreateFulltextIndexContext;
    TEXT(): TerminalNode;
    POINT(): TerminalNode;
    LOOKUP(): TerminalNode;
    createLookupIndex(): CreateLookupIndexContext;
    ON(): TerminalNode;
    oldCreateIndex(): OldCreateIndexContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class OldCreateIndexContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    labelOrRelType(): LabelOrRelTypeContext;
    LPAREN(): TerminalNode;
    symbolicNamePositions(): SymbolicNamePositionsContext;
    RPAREN(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateIndex_Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ON(): TerminalNode;
    propertyList(): PropertyListContext;
    FOR(): TerminalNode;
    LPAREN_list(): TerminalNode[];
    LPAREN(i: number): TerminalNode;
    IF(): TerminalNode;
    NOT(): TerminalNode;
    EXISTS(): TerminalNode;
    symbolicNameString(): SymbolicNameStringContext;
    variable(): VariableContext;
    labelOrRelType(): LabelOrRelTypeContext;
    RPAREN_list(): TerminalNode[];
    RPAREN(i: number): TerminalNode;
    arrowLine_list(): ArrowLineContext[];
    arrowLine(i: number): ArrowLineContext;
    LBRACKET(): TerminalNode;
    RBRACKET(): TerminalNode;
    OPTIONS(): TerminalNode;
    mapOrParameter(): MapOrParameterContext;
    leftArrow(): LeftArrowContext;
    rightArrow(): RightArrowContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateFulltextIndexContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ON(): TerminalNode;
    EACH(): TerminalNode;
    LBRACKET_list(): TerminalNode[];
    LBRACKET(i: number): TerminalNode;
    variable_list(): VariableContext[];
    variable(i: number): VariableContext;
    property_list(): PropertyContext[];
    property(i: number): PropertyContext;
    RBRACKET_list(): TerminalNode[];
    RBRACKET(i: number): TerminalNode;
    FOR(): TerminalNode;
    LPAREN_list(): TerminalNode[];
    LPAREN(i: number): TerminalNode;
    IF(): TerminalNode;
    NOT(): TerminalNode;
    EXISTS(): TerminalNode;
    symbolicNameString(): SymbolicNameStringContext;
    labelOrRelTypes(): LabelOrRelTypesContext;
    RPAREN_list(): TerminalNode[];
    RPAREN(i: number): TerminalNode;
    arrowLine_list(): ArrowLineContext[];
    arrowLine(i: number): ArrowLineContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    OPTIONS(): TerminalNode;
    mapOrParameter(): MapOrParameterContext;
    leftArrow(): LeftArrowContext;
    rightArrow(): RightArrowContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateLookupIndexContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    lookupIndexFunctionName(): LookupIndexFunctionNameContext;
    LPAREN_list(): TerminalNode[];
    LPAREN(i: number): TerminalNode;
    variable_list(): VariableContext[];
    variable(i: number): VariableContext;
    RPAREN_list(): TerminalNode[];
    RPAREN(i: number): TerminalNode;
    FOR(): TerminalNode;
    IF(): TerminalNode;
    NOT(): TerminalNode;
    EXISTS(): TerminalNode;
    symbolicNameString(): SymbolicNameStringContext;
    ON(): TerminalNode;
    EACH(): TerminalNode;
    arrowLine_list(): ArrowLineContext[];
    arrowLine(i: number): ArrowLineContext;
    LBRACKET(): TerminalNode;
    RBRACKET(): TerminalNode;
    OPTIONS(): TerminalNode;
    mapOrParameter(): MapOrParameterContext;
    leftArrow(): LeftArrowContext;
    rightArrow(): RightArrowContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LookupIndexFunctionNameContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameString(): SymbolicNameStringContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DropIndexContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    INDEX(): TerminalNode;
    ON(): TerminalNode;
    labelOrRelType(): LabelOrRelTypeContext;
    LPAREN(): TerminalNode;
    symbolicNamePositions(): SymbolicNamePositionsContext;
    RPAREN(): TerminalNode;
    symbolicNameString(): SymbolicNameStringContext;
    IF(): TerminalNode;
    EXISTS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PropertyListContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    variable_list(): VariableContext[];
    variable(i: number): VariableContext;
    property_list(): PropertyContext[];
    property(i: number): PropertyContext;
    LPAREN(): TerminalNode;
    RPAREN(): TerminalNode;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RenameCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    RENAME(): TerminalNode;
    renameRole(): RenameRoleContext;
    renameUser(): RenameUserContext;
    renameServer(): RenameServerContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class GrantCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    GRANT(): TerminalNode;
    IMMUTABLE(): TerminalNode;
    grantPrivilege(): GrantPrivilegeContext;
    ROLE(): TerminalNode;
    grantRoleManagement(): GrantRoleManagementContext;
    ROLES(): TerminalNode;
    grantRole(): GrantRoleContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RevokeCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    REVOKE(): TerminalNode;
    DENY(): TerminalNode;
    GRANT(): TerminalNode;
    IMMUTABLE(): TerminalNode;
    revokePrivilege(): RevokePrivilegeContext;
    ROLE(): TerminalNode;
    revokeRoleManagement(): RevokeRoleManagementContext;
    revokeRole(): RevokeRoleContext;
    ROLES(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class EnableServerCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ENABLE(): TerminalNode;
    SERVER(): TerminalNode;
    stringOrParameter(): StringOrParameterContext;
    options_(): Options_Context;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AlterServerContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    SERVER(): TerminalNode;
    stringOrParameter(): StringOrParameterContext;
    SET(): TerminalNode;
    options_(): Options_Context;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RenameServerContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    SERVER(): TerminalNode;
    stringOrParameter_list(): StringOrParameterContext[];
    stringOrParameter(i: number): StringOrParameterContext;
    TO(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DropServerContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    SERVER(): TerminalNode;
    stringOrParameter(): StringOrParameterContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowServersContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    SERVERS(): TerminalNode;
    SERVER(): TerminalNode;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AllocationCommandContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    deallocateDatabaseFromServers(): DeallocateDatabaseFromServersContext;
    reallocateDatabases(): ReallocateDatabasesContext;
    DRYRUN(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DeallocateDatabaseFromServersContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DEALLOCATE(): TerminalNode;
    FROM(): TerminalNode;
    stringOrParameter_list(): StringOrParameterContext[];
    stringOrParameter(i: number): StringOrParameterContext;
    DATABASE(): TerminalNode;
    DATABASES(): TerminalNode;
    SERVER(): TerminalNode;
    SERVERS(): TerminalNode;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ReallocateDatabasesContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    REALLOCATE(): TerminalNode;
    DATABASE(): TerminalNode;
    DATABASES(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateRoleContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ROLE(): TerminalNode;
    symbolicNameOrStringParameter_list(): SymbolicNameOrStringParameterContext[];
    symbolicNameOrStringParameter(i: number): SymbolicNameOrStringParameterContext;
    IF(): TerminalNode;
    NOT(): TerminalNode;
    EXISTS(): TerminalNode;
    AS(): TerminalNode;
    COPY(): TerminalNode;
    OF(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DropRoleContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ROLE(): TerminalNode;
    symbolicNameOrStringParameter(): SymbolicNameOrStringParameterContext;
    IF(): TerminalNode;
    EXISTS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RenameRoleContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ROLE(): TerminalNode;
    symbolicNameOrStringParameter_list(): SymbolicNameOrStringParameterContext[];
    symbolicNameOrStringParameter(i: number): SymbolicNameOrStringParameterContext;
    TO(): TerminalNode;
    IF(): TerminalNode;
    EXISTS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowRolesContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    WITH(): TerminalNode;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    USERS(): TerminalNode;
    USER(): TerminalNode;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class GrantRoleContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameOrStringParameterList_list(): SymbolicNameOrStringParameterListContext[];
    symbolicNameOrStringParameterList(i: number): SymbolicNameOrStringParameterListContext;
    TO(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RevokeRoleContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameOrStringParameterList_list(): SymbolicNameOrStringParameterListContext[];
    symbolicNameOrStringParameterList(i: number): SymbolicNameOrStringParameterListContext;
    FROM(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateUserContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    USER(): TerminalNode;
    symbolicNameOrStringParameter(): SymbolicNameOrStringParameterContext;
    SET_list(): TerminalNode[];
    SET(i: number): TerminalNode;
    PASSWORD_list(): TerminalNode[];
    PASSWORD(i: number): TerminalNode;
    passwordExpression(): PasswordExpressionContext;
    IF(): TerminalNode;
    NOT(): TerminalNode;
    EXISTS(): TerminalNode;
    passwordChangeRequired_list(): PasswordChangeRequiredContext[];
    passwordChangeRequired(i: number): PasswordChangeRequiredContext;
    PLAINTEXT(): TerminalNode;
    ENCRYPTED(): TerminalNode;
    userStatus_list(): UserStatusContext[];
    userStatus(i: number): UserStatusContext;
    homeDatabase_list(): HomeDatabaseContext[];
    homeDatabase(i: number): HomeDatabaseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DropUserContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    USER(): TerminalNode;
    symbolicNameOrStringParameter(): SymbolicNameOrStringParameterContext;
    IF(): TerminalNode;
    EXISTS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RenameUserContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    USER(): TerminalNode;
    symbolicNameOrStringParameter_list(): SymbolicNameOrStringParameterContext[];
    symbolicNameOrStringParameter(i: number): SymbolicNameOrStringParameterContext;
    TO(): TerminalNode;
    IF(): TerminalNode;
    EXISTS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AlterCurrentUserContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CURRENT(): TerminalNode;
    USER(): TerminalNode;
    SET(): TerminalNode;
    PASSWORD(): TerminalNode;
    FROM(): TerminalNode;
    passwordExpression_list(): PasswordExpressionContext[];
    passwordExpression(i: number): PasswordExpressionContext;
    TO(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AlterUserContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    USER(): TerminalNode;
    symbolicNameOrStringParameter(): SymbolicNameOrStringParameterContext;
    REMOVE(): TerminalNode;
    HOME(): TerminalNode;
    DATABASE(): TerminalNode;
    IF(): TerminalNode;
    EXISTS(): TerminalNode;
    SET_list(): TerminalNode[];
    SET(i: number): TerminalNode;
    PLAINTEXT_list(): TerminalNode[];
    PLAINTEXT(i: number): TerminalNode;
    PASSWORD_list(): TerminalNode[];
    PASSWORD(i: number): TerminalNode;
    setPassword_list(): SetPasswordContext[];
    setPassword(i: number): SetPasswordContext;
    ENCRYPTED_list(): TerminalNode[];
    ENCRYPTED(i: number): TerminalNode;
    userStatus_list(): UserStatusContext[];
    userStatus(i: number): UserStatusContext;
    homeDatabase_list(): HomeDatabaseContext[];
    homeDatabase(i: number): HomeDatabaseContext;
    passwordChangeRequired_list(): PasswordChangeRequiredContext[];
    passwordChangeRequired(i: number): PasswordChangeRequiredContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SetPasswordContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    passwordExpression(): PasswordExpressionContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PasswordExpressionContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    stringToken(): StringTokenContext;
    parameter(): ParameterContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PasswordChangeRequiredContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CHANGE(): TerminalNode;
    REQUIRED(): TerminalNode;
    NOT(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class UserStatusContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    STATUS(): TerminalNode;
    SUSPENDED(): TerminalNode;
    ACTIVE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class HomeDatabaseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    HOME(): TerminalNode;
    DATABASE(): TerminalNode;
    symbolicAliasName(): SymbolicAliasNameContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowUsersContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowCurrentUserContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CURRENT(): TerminalNode;
    USER(): TerminalNode;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowSupportedPrivilegesContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    SUPPORTED(): TerminalNode;
    PRIVILEGE(): TerminalNode;
    PRIVILEGES(): TerminalNode;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowPrivilegesContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    PRIVILEGE(): TerminalNode;
    PRIVILEGES(): TerminalNode;
    AS(): TerminalNode;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    COMMAND(): TerminalNode;
    COMMANDS(): TerminalNode;
    REVOKE(): TerminalNode;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowRolePrivilegesContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameOrStringParameterList(): SymbolicNameOrStringParameterListContext;
    PRIVILEGE(): TerminalNode;
    PRIVILEGES(): TerminalNode;
    AS(): TerminalNode;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    COMMAND(): TerminalNode;
    COMMANDS(): TerminalNode;
    REVOKE(): TerminalNode;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowUserPrivilegesContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameOrStringParameterList(): SymbolicNameOrStringParameterListContext;
    PRIVILEGE(): TerminalNode;
    PRIVILEGES(): TerminalNode;
    AS(): TerminalNode;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    COMMAND(): TerminalNode;
    COMMANDS(): TerminalNode;
    REVOKE(): TerminalNode;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class GrantRoleManagementContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    roleManagementPrivilege(): RoleManagementPrivilegeContext;
    TO(): TerminalNode;
    symbolicNameOrStringParameterList(): SymbolicNameOrStringParameterListContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RevokeRoleManagementContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    roleManagementPrivilege(): RoleManagementPrivilegeContext;
    FROM(): TerminalNode;
    symbolicNameOrStringParameterList(): SymbolicNameOrStringParameterListContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RoleManagementPrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    MANAGEMENT(): TerminalNode;
    ON(): TerminalNode;
    DBMS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class GrantPrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    privilege(): PrivilegeContext;
    TO(): TerminalNode;
    symbolicNameOrStringParameterList(): SymbolicNameOrStringParameterListContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DenyPrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DENY(): TerminalNode;
    TO(): TerminalNode;
    symbolicNameOrStringParameterList(): SymbolicNameOrStringParameterListContext;
    privilege(): PrivilegeContext;
    ROLE(): TerminalNode;
    roleManagementPrivilege(): RoleManagementPrivilegeContext;
    IMMUTABLE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RevokePrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    privilege(): PrivilegeContext;
    FROM(): TerminalNode;
    symbolicNameOrStringParameterList(): SymbolicNameOrStringParameterListContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    allPrivilege(): AllPrivilegeContext;
    createPrivilege(): CreatePrivilegeContext;
    dropPrivilege(): DropPrivilegeContext;
    loadPrivilege(): LoadPrivilegeContext;
    showPrivilege(): ShowPrivilegeContext;
    setPrivilege(): SetPrivilegeContext;
    removePrivilege(): RemovePrivilegeContext;
    databasePrivilege(): DatabasePrivilegeContext;
    dbmsPrivilege(): DbmsPrivilegeContext;
    writePrivilege(): WritePrivilegeContext;
    qualifiedGraphPrivileges(): QualifiedGraphPrivilegesContext;
    qualifiedGraphPrivilegesWithProperty(): QualifiedGraphPrivilegesWithPropertyContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AllPrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ALL(): TerminalNode;
    ON(): TerminalNode;
    allPrivilegeTarget(): AllPrivilegeTargetContext;
    allPrivilegeType(): AllPrivilegeTypeContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AllPrivilegeTypeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    PRIVILEGES(): TerminalNode;
    DBMS(): TerminalNode;
    GRAPH(): TerminalNode;
    DATABASE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AllPrivilegeTargetContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DEFAULT(): TerminalNode;
    GRAPH(): TerminalNode;
    DATABASE(): TerminalNode;
    HOME(): TerminalNode;
    DBMS(): TerminalNode;
    GRAPHS(): TerminalNode;
    TIMES(): TerminalNode;
    symbolicAliasNameList(): SymbolicAliasNameListContext;
    DATABASES(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreatePrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    CREATE(): TerminalNode;
    ON(): TerminalNode;
    databaseScope(): DatabaseScopeContext;
    DBMS(): TerminalNode;
    graphScope(): GraphScopeContext;
    graphQualifier(): GraphQualifierContext;
    NEW(): TerminalNode;
    DATABASE(): TerminalNode;
    ALIAS(): TerminalNode;
    ROLE(): TerminalNode;
    USER(): TerminalNode;
    COMPOSITE(): TerminalNode;
    INDEX(): TerminalNode;
    INDEXES(): TerminalNode;
    CONSTRAINT(): TerminalNode;
    CONSTRAINTS(): TerminalNode;
    LABEL(): TerminalNode;
    LABELS(): TerminalNode;
    TYPE(): TerminalNode;
    TYPES(): TerminalNode;
    NAME(): TerminalNode;
    NAMES(): TerminalNode;
    NODE(): TerminalNode;
    RELATIONSHIP(): TerminalNode;
    PROPERTY(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DropPrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DROP(): TerminalNode;
    ON(): TerminalNode;
    databaseScope(): DatabaseScopeContext;
    DBMS(): TerminalNode;
    DATABASE(): TerminalNode;
    ALIAS(): TerminalNode;
    ROLE(): TerminalNode;
    USER(): TerminalNode;
    COMPOSITE(): TerminalNode;
    INDEX(): TerminalNode;
    INDEXES(): TerminalNode;
    CONSTRAINT(): TerminalNode;
    CONSTRAINTS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LoadPrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    LOAD(): TerminalNode;
    ON(): TerminalNode;
    URL(): TerminalNode;
    stringOrParameter(): StringOrParameterContext;
    CIDR(): TerminalNode;
    ALL(): TerminalNode;
    DATA(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowPrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    SHOW(): TerminalNode;
    ON(): TerminalNode;
    databaseScope(): DatabaseScopeContext;
    DBMS(): TerminalNode;
    ALIAS(): TerminalNode;
    PRIVILEGE(): TerminalNode;
    ROLE(): TerminalNode;
    USER(): TerminalNode;
    settingQualifier(): SettingQualifierContext;
    INDEX(): TerminalNode;
    INDEXES(): TerminalNode;
    CONSTRAINT(): TerminalNode;
    CONSTRAINTS(): TerminalNode;
    TRANSACTION(): TerminalNode;
    TRANSACTIONS(): TerminalNode;
    SERVER(): TerminalNode;
    SERVERS(): TerminalNode;
    SETTING(): TerminalNode;
    SETTINGS(): TerminalNode;
    LPAREN(): TerminalNode;
    RPAREN(): TerminalNode;
    TIMES(): TerminalNode;
    symbolicNameOrStringParameterList(): SymbolicNameOrStringParameterListContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SetPrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    SET(): TerminalNode;
    ON(): TerminalNode;
    DBMS(): TerminalNode;
    USER(): TerminalNode;
    DATABASE(): TerminalNode;
    ACCESS(): TerminalNode;
    LABEL(): TerminalNode;
    labelResource(): LabelResourceContext;
    graphScope(): GraphScopeContext;
    PROPERTY(): TerminalNode;
    propertyResource(): PropertyResourceContext;
    graphQualifier(): GraphQualifierContext;
    PASSWORD(): TerminalNode;
    PASSWORDS(): TerminalNode;
    STATUS(): TerminalNode;
    HOME(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class RemovePrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    REMOVE(): TerminalNode;
    ON(): TerminalNode;
    DBMS(): TerminalNode;
    LABEL(): TerminalNode;
    labelResource(): LabelResourceContext;
    graphScope(): GraphScopeContext;
    PRIVILEGE(): TerminalNode;
    ROLE(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class WritePrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    WRITE(): TerminalNode;
    ON(): TerminalNode;
    graphScope(): GraphScopeContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DatabasePrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ON(): TerminalNode;
    databaseScope(): DatabaseScopeContext;
    ACCESS(): TerminalNode;
    START(): TerminalNode;
    STOP(): TerminalNode;
    TRANSACTION(): TerminalNode;
    TERMINATE(): TerminalNode;
    NAME(): TerminalNode;
    INDEX(): TerminalNode;
    INDEXES(): TerminalNode;
    CONSTRAINT(): TerminalNode;
    CONSTRAINTS(): TerminalNode;
    TRANSACTIONS(): TerminalNode;
    MANAGEMENT(): TerminalNode;
    LPAREN(): TerminalNode;
    RPAREN(): TerminalNode;
    TIMES(): TerminalNode;
    symbolicNameOrStringParameterList(): SymbolicNameOrStringParameterListContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DbmsPrivilegeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ON(): TerminalNode;
    DBMS(): TerminalNode;
    ALTER(): TerminalNode;
    ASSIGN(): TerminalNode;
    COMPOSITE(): TerminalNode;
    DATABASE(): TerminalNode;
    MANAGEMENT(): TerminalNode;
    ALIAS(): TerminalNode;
    EXECUTE(): TerminalNode;
    PRIVILEGE(): TerminalNode;
    RENAME(): TerminalNode;
    SERVER(): TerminalNode;
    USER(): TerminalNode;
    IMPERSONATE(): TerminalNode;
    ROLE(): TerminalNode;
    PROCEDURES(): TerminalNode;
    BOOSTED(): TerminalNode;
    executeProcedureQualifier(): ExecuteProcedureQualifierContext;
    executeFunctionQualifier(): ExecuteFunctionQualifierContext;
    ADMIN(): TerminalNode;
    ADMINISTRATOR(): TerminalNode;
    PROCEDURE(): TerminalNode;
    FUNCTION(): TerminalNode;
    FUNCTIONS(): TerminalNode;
    LPAREN(): TerminalNode;
    RPAREN(): TerminalNode;
    TIMES(): TerminalNode;
    symbolicNameOrStringParameterList(): SymbolicNameOrStringParameterListContext;
    DEFINED(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ExecuteFunctionQualifierContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    globs(): GlobsContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ExecuteProcedureQualifierContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    globs(): GlobsContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SettingQualifierContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    globs(): GlobsContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class GlobsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    glob_list(): GlobContext[];
    glob(i: number): GlobContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class QualifiedGraphPrivilegesWithPropertyContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ON(): TerminalNode;
    graphScope(): GraphScopeContext;
    graphQualifier(): GraphQualifierContext;
    TRAVERSE(): TerminalNode;
    READ(): TerminalNode;
    propertyResource(): PropertyResourceContext;
    MATCH(): TerminalNode;
    LPAREN(): TerminalNode;
    TIMES(): TerminalNode;
    RPAREN(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class QualifiedGraphPrivilegesContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ON(): TerminalNode;
    graphScope(): GraphScopeContext;
    graphQualifier(): GraphQualifierContext;
    DELETE(): TerminalNode;
    MERGE(): TerminalNode;
    propertyResource(): PropertyResourceContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class LabelResourceContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    TIMES(): TerminalNode;
    symbolicNameList1(): SymbolicNameList1Context;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class PropertyResourceContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    LCURLY(): TerminalNode;
    RCURLY(): TerminalNode;
    TIMES(): TerminalNode;
    symbolicNameList1(): SymbolicNameList1Context;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class GraphQualifierContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    FOR(): TerminalNode;
    LPAREN(): TerminalNode;
    RELATIONSHIP(): TerminalNode;
    RELATIONSHIPS(): TerminalNode;
    NODE(): TerminalNode;
    NODES(): TerminalNode;
    ELEMENT(): TerminalNode;
    ELEMENTS(): TerminalNode;
    TIMES(): TerminalNode;
    symbolicNameString_list(): SymbolicNameStringContext[];
    symbolicNameString(i: number): SymbolicNameStringContext;
    RPAREN(): TerminalNode;
    WHERE(): TerminalNode;
    expression(): ExpressionContext;
    mapLiteral(): MapLiteralContext;
    variable(): VariableContext;
    labelOrRelTypes(): LabelOrRelTypesContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateDatabaseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DATABASE(): TerminalNode;
    symbolicAliasName(): SymbolicAliasNameContext;
    IF(): TerminalNode;
    NOT(): TerminalNode;
    EXISTS(): TerminalNode;
    TOPOLOGY(): TerminalNode;
    options_(): Options_Context;
    waitClause(): WaitClauseContext;
    UNSIGNED_DECIMAL_INTEGER_list(): TerminalNode[];
    UNSIGNED_DECIMAL_INTEGER(i: number): TerminalNode;
    PRIMARY_list(): TerminalNode[];
    PRIMARY(i: number): TerminalNode;
    PRIMARIES_list(): TerminalNode[];
    PRIMARIES(i: number): TerminalNode;
    SECONDARY_list(): TerminalNode[];
    SECONDARY(i: number): TerminalNode;
    SECONDARIES_list(): TerminalNode[];
    SECONDARIES(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class Options_Context extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    OPTIONS(): TerminalNode;
    mapOrParameter(): MapOrParameterContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateCompositeDatabaseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    COMPOSITE(): TerminalNode;
    DATABASE(): TerminalNode;
    symbolicAliasName(): SymbolicAliasNameContext;
    IF(): TerminalNode;
    NOT(): TerminalNode;
    EXISTS(): TerminalNode;
    options_(): Options_Context;
    waitClause(): WaitClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DropDatabaseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DATABASE(): TerminalNode;
    symbolicAliasName(): SymbolicAliasNameContext;
    COMPOSITE(): TerminalNode;
    IF(): TerminalNode;
    EXISTS(): TerminalNode;
    DATA(): TerminalNode;
    waitClause(): WaitClauseContext;
    DUMP(): TerminalNode;
    DESTROY(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AlterDatabaseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DATABASE(): TerminalNode;
    symbolicAliasName(): SymbolicAliasNameContext;
    IF(): TerminalNode;
    EXISTS(): TerminalNode;
    waitClause(): WaitClauseContext;
    SET_list(): TerminalNode[];
    SET(i: number): TerminalNode;
    REMOVE_list(): TerminalNode[];
    REMOVE(i: number): TerminalNode;
    OPTION_list(): TerminalNode[];
    OPTION(i: number): TerminalNode;
    symbolicNameString_list(): SymbolicNameStringContext[];
    symbolicNameString(i: number): SymbolicNameStringContext;
    ACCESS_list(): TerminalNode[];
    ACCESS(i: number): TerminalNode;
    READ_list(): TerminalNode[];
    READ(i: number): TerminalNode;
    TOPOLOGY_list(): TerminalNode[];
    TOPOLOGY(i: number): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    ONLY_list(): TerminalNode[];
    ONLY(i: number): TerminalNode;
    WRITE_list(): TerminalNode[];
    WRITE(i: number): TerminalNode;
    UNSIGNED_DECIMAL_INTEGER_list(): TerminalNode[];
    UNSIGNED_DECIMAL_INTEGER(i: number): TerminalNode;
    PRIMARY_list(): TerminalNode[];
    PRIMARY(i: number): TerminalNode;
    PRIMARIES_list(): TerminalNode[];
    PRIMARIES(i: number): TerminalNode;
    SECONDARY_list(): TerminalNode[];
    SECONDARY(i: number): TerminalNode;
    SECONDARIES_list(): TerminalNode[];
    SECONDARIES(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class StartDatabaseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    START(): TerminalNode;
    DATABASE(): TerminalNode;
    symbolicAliasName(): SymbolicAliasNameContext;
    waitClause(): WaitClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class StopDatabaseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    STOP(): TerminalNode;
    DATABASE(): TerminalNode;
    symbolicAliasName(): SymbolicAliasNameContext;
    waitClause(): WaitClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class WaitClauseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    WAIT(): TerminalNode;
    NOWAIT(): TerminalNode;
    UNSIGNED_DECIMAL_INTEGER(): TerminalNode;
    SEC(): TerminalNode;
    SECOND(): TerminalNode;
    SECONDS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowDatabaseContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DATABASES(): TerminalNode;
    DATABASE(): TerminalNode;
    DEFAULT(): TerminalNode;
    HOME(): TerminalNode;
    symbolicAliasName(): SymbolicAliasNameContext;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DatabaseScopeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DEFAULT(): TerminalNode;
    DATABASE(): TerminalNode;
    HOME(): TerminalNode;
    DATABASES(): TerminalNode;
    TIMES(): TerminalNode;
    symbolicAliasNameList(): SymbolicAliasNameListContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class GraphScopeContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DEFAULT(): TerminalNode;
    GRAPH(): TerminalNode;
    HOME(): TerminalNode;
    GRAPHS(): TerminalNode;
    TIMES(): TerminalNode;
    symbolicAliasNameList(): SymbolicAliasNameListContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class CreateAliasContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ALIAS(): TerminalNode;
    symbolicAliasName_list(): SymbolicAliasNameContext[];
    symbolicAliasName(i: number): SymbolicAliasNameContext;
    FOR(): TerminalNode;
    DATABASE(): TerminalNode;
    IF(): TerminalNode;
    NOT(): TerminalNode;
    EXISTS(): TerminalNode;
    AT(): TerminalNode;
    stringOrParameter(): StringOrParameterContext;
    USER(): TerminalNode;
    symbolicNameOrStringParameter(): SymbolicNameOrStringParameterContext;
    PASSWORD(): TerminalNode;
    passwordExpression(): PasswordExpressionContext;
    PROPERTIES(): TerminalNode;
    mapOrParameter_list(): MapOrParameterContext[];
    mapOrParameter(i: number): MapOrParameterContext;
    DRIVER(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class DropAliasContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ALIAS(): TerminalNode;
    symbolicAliasName(): SymbolicAliasNameContext;
    FOR(): TerminalNode;
    DATABASE(): TerminalNode;
    IF(): TerminalNode;
    EXISTS(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class AlterAliasContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ALIAS(): TerminalNode;
    symbolicAliasName_list(): SymbolicAliasNameContext[];
    symbolicAliasName(i: number): SymbolicAliasNameContext;
    SET(): TerminalNode;
    DATABASE(): TerminalNode;
    IF(): TerminalNode;
    EXISTS(): TerminalNode;
    TARGET_list(): TerminalNode[];
    TARGET(i: number): TerminalNode;
    USER_list(): TerminalNode[];
    USER(i: number): TerminalNode;
    symbolicNameOrStringParameter_list(): SymbolicNameOrStringParameterContext[];
    symbolicNameOrStringParameter(i: number): SymbolicNameOrStringParameterContext;
    PASSWORD_list(): TerminalNode[];
    PASSWORD(i: number): TerminalNode;
    passwordExpression_list(): PasswordExpressionContext[];
    passwordExpression(i: number): PasswordExpressionContext;
    DRIVER_list(): TerminalNode[];
    DRIVER(i: number): TerminalNode;
    mapOrParameter_list(): MapOrParameterContext[];
    mapOrParameter(i: number): MapOrParameterContext;
    PROPERTIES_list(): TerminalNode[];
    PROPERTIES(i: number): TerminalNode;
    AT_list(): TerminalNode[];
    AT(i: number): TerminalNode;
    stringOrParameter_list(): StringOrParameterContext[];
    stringOrParameter(i: number): StringOrParameterContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class ShowAliasesContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    FOR(): TerminalNode;
    ALIAS(): TerminalNode;
    ALIASES(): TerminalNode;
    DATABASE(): TerminalNode;
    DATABASES(): TerminalNode;
    symbolicAliasName(): SymbolicAliasNameContext;
    yieldClause(): YieldClauseContext;
    whereClause(): WhereClauseContext;
    returnClause(): ReturnClauseContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SymbolicAliasNameListContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicAliasName_list(): SymbolicAliasNameContext[];
    symbolicAliasName(i: number): SymbolicAliasNameContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SymbolicAliasNameContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameString_list(): SymbolicNameStringContext[];
    symbolicNameString(i: number): SymbolicNameStringContext;
    parameter(): ParameterContext;
    DOT_list(): TerminalNode[];
    DOT(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SymbolicNameOrStringParameterListContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameOrStringParameter_list(): SymbolicNameOrStringParameterContext[];
    symbolicNameOrStringParameter(i: number): SymbolicNameOrStringParameterContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SymbolicNameOrStringParameterContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameString(): SymbolicNameStringContext;
    parameter(): ParameterContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class GlobContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    escapedSymbolicNameString(): EscapedSymbolicNameStringContext;
    globRecursive(): GlobRecursiveContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class GlobRecursiveContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    globPart(): GlobPartContext;
    globRecursive(): GlobRecursiveContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class GlobPartContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    DOT(): TerminalNode;
    escapedSymbolicNameString(): EscapedSymbolicNameStringContext;
    QUESTION(): TerminalNode;
    TIMES(): TerminalNode;
    unescapedSymbolicNameString(): UnescapedSymbolicNameStringContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class StringImageContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    stringToken(): StringTokenContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class StringListContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    stringImage_list(): StringImageContext[];
    stringImage(i: number): StringImageContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class StringTokenContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    STRING_LITERAL1(): TerminalNode;
    STRING_LITERAL2(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class StringOrParameterContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    stringToken(): StringTokenContext;
    parameter(): ParameterContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class MapOrParameterContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    map(): MapContext;
    parameter(): ParameterContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class MapContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    LCURLY(): TerminalNode;
    RCURLY(): TerminalNode;
    symbolicNameString_list(): SymbolicNameStringContext[];
    symbolicNameString(i: number): SymbolicNameStringContext;
    COLON_list(): TerminalNode[];
    COLON(i: number): TerminalNode;
    expression_list(): ExpressionContext[];
    expression(i: number): ExpressionContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SymbolicNamePositionsContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    symbolicNameString_list(): SymbolicNameStringContext[];
    symbolicNameString(i: number): SymbolicNameStringContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SymbolicNameStringContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    escapedSymbolicNameString(): EscapedSymbolicNameStringContext;
    unescapedSymbolicNameString(): UnescapedSymbolicNameStringContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class EscapedSymbolicNameStringContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    ESCAPED_SYMBOLIC_NAME(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class UnescapedSymbolicNameStringContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    unescapedLabelSymbolicNameString(): UnescapedLabelSymbolicNameStringContext;
    NOT(): TerminalNode;
    NULL(): TerminalNode;
    TYPED(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class SymbolicLabelNameStringContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    escapedSymbolicNameString(): EscapedSymbolicNameStringContext;
    unescapedLabelSymbolicNameString(): UnescapedLabelSymbolicNameStringContext;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class UnescapedLabelSymbolicNameStringContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    IDENTIFIER(): TerminalNode;
    ACCESS(): TerminalNode;
    ACTIVE(): TerminalNode;
    ADMIN(): TerminalNode;
    ADMINISTRATOR(): TerminalNode;
    ALIAS(): TerminalNode;
    ALIASES(): TerminalNode;
    ALL_SHORTEST_PATH(): TerminalNode;
    ALL(): TerminalNode;
    ALTER(): TerminalNode;
    AND(): TerminalNode;
    ANY(): TerminalNode;
    ARRAY(): TerminalNode;
    AS(): TerminalNode;
    ASC(): TerminalNode;
    ASSERT(): TerminalNode;
    ASSIGN(): TerminalNode;
    AT(): TerminalNode;
    BINDINGS(): TerminalNode;
    BOOL(): TerminalNode;
    BOOLEAN(): TerminalNode;
    BOOSTED(): TerminalNode;
    BREAK(): TerminalNode;
    BRIEF(): TerminalNode;
    BTREE(): TerminalNode;
    BUILT(): TerminalNode;
    BY(): TerminalNode;
    CALL(): TerminalNode;
    CASE(): TerminalNode;
    CHANGE(): TerminalNode;
    CIDR(): TerminalNode;
    COLLECT(): TerminalNode;
    COMMAND(): TerminalNode;
    COMMANDS(): TerminalNode;
    COMMIT(): TerminalNode;
    COMPOSITE(): TerminalNode;
    CONSTRAINT(): TerminalNode;
    CONSTRAINTS(): TerminalNode;
    CONTAINS(): TerminalNode;
    CONTINUE(): TerminalNode;
    COPY(): TerminalNode;
    COUNT(): TerminalNode;
    CREATE(): TerminalNode;
    CSV(): TerminalNode;
    CURRENT(): TerminalNode;
    DATA(): TerminalNode;
    DATABASE(): TerminalNode;
    DATABASES(): TerminalNode;
    DATE(): TerminalNode;
    DATETIME(): TerminalNode;
    DBMS(): TerminalNode;
    DEALLOCATE(): TerminalNode;
    DEFAULT(): TerminalNode;
    DEFINED(): TerminalNode;
    DELETE(): TerminalNode;
    DENY(): TerminalNode;
    DESC(): TerminalNode;
    DESTROY(): TerminalNode;
    DETACH(): TerminalNode;
    DIFFERENT(): TerminalNode;
    DISTINCT(): TerminalNode;
    DRIVER(): TerminalNode;
    DROP(): TerminalNode;
    DRYRUN(): TerminalNode;
    DUMP(): TerminalNode;
    DURATION(): TerminalNode;
    EACH(): TerminalNode;
    EDGE(): TerminalNode;
    ELEMENT(): TerminalNode;
    ELEMENTS(): TerminalNode;
    ELSE(): TerminalNode;
    ENABLE(): TerminalNode;
    ENCRYPTED(): TerminalNode;
    END(): TerminalNode;
    ENDS(): TerminalNode;
    ERROR(): TerminalNode;
    EXECUTABLE(): TerminalNode;
    EXECUTE(): TerminalNode;
    EXIST(): TerminalNode;
    EXISTENCE(): TerminalNode;
    EXISTS(): TerminalNode;
    FAIL(): TerminalNode;
    FALSE(): TerminalNode;
    FIELDTERMINATOR(): TerminalNode;
    FLOAT(): TerminalNode;
    FOREACH(): TerminalNode;
    FOR(): TerminalNode;
    FROM(): TerminalNode;
    FULLTEXT(): TerminalNode;
    FUNCTION(): TerminalNode;
    FUNCTIONS(): TerminalNode;
    GRANT(): TerminalNode;
    GRAPH(): TerminalNode;
    GRAPHS(): TerminalNode;
    GROUP(): TerminalNode;
    GROUPS(): TerminalNode;
    HEADERS(): TerminalNode;
    HOME(): TerminalNode;
    IF(): TerminalNode;
    IMMUTABLE(): TerminalNode;
    IN(): TerminalNode;
    INDEX(): TerminalNode;
    INDEXES(): TerminalNode;
    INF(): TerminalNode;
    INFINITY(): TerminalNode;
    INT(): TerminalNode;
    INTEGER(): TerminalNode;
    IS(): TerminalNode;
    JOIN(): TerminalNode;
    KEY(): TerminalNode;
    LABEL(): TerminalNode;
    LABELS(): TerminalNode;
    LIMITROWS(): TerminalNode;
    LIST(): TerminalNode;
    LOAD(): TerminalNode;
    LOCAL(): TerminalNode;
    LOOKUP(): TerminalNode;
    MATCH(): TerminalNode;
    MANAGEMENT(): TerminalNode;
    MAP(): TerminalNode;
    MERGE(): TerminalNode;
    NAME(): TerminalNode;
    NAMES(): TerminalNode;
    NAN(): TerminalNode;
    NEW(): TerminalNode;
    NODE(): TerminalNode;
    NODES(): TerminalNode;
    NONE(): TerminalNode;
    NOTHING(): TerminalNode;
    NOWAIT(): TerminalNode;
    OF(): TerminalNode;
    ON(): TerminalNode;
    ONLY(): TerminalNode;
    OPTIONAL(): TerminalNode;
    OPTIONS(): TerminalNode;
    OPTION(): TerminalNode;
    OR(): TerminalNode;
    ORDER(): TerminalNode;
    OUTPUT(): TerminalNode;
    PASSWORD(): TerminalNode;
    PASSWORDS(): TerminalNode;
    PATH(): TerminalNode;
    PATHS(): TerminalNode;
    PERIODIC(): TerminalNode;
    PLAINTEXT(): TerminalNode;
    POINT(): TerminalNode;
    POPULATED(): TerminalNode;
    PRIMARY(): TerminalNode;
    PRIMARIES(): TerminalNode;
    PRIVILEGE(): TerminalNode;
    PRIVILEGES(): TerminalNode;
    PROCEDURE(): TerminalNode;
    PROCEDURES(): TerminalNode;
    PROPERTIES(): TerminalNode;
    PROPERTY(): TerminalNode;
    RANGE(): TerminalNode;
    READ(): TerminalNode;
    REALLOCATE(): TerminalNode;
    REDUCE(): TerminalNode;
    REL(): TerminalNode;
    RELATIONSHIP(): TerminalNode;
    RELATIONSHIPS(): TerminalNode;
    REMOVE(): TerminalNode;
    RENAME(): TerminalNode;
    REPEATABLE(): TerminalNode;
    REPLACE(): TerminalNode;
    REPORT(): TerminalNode;
    REQUIRE(): TerminalNode;
    REQUIRED(): TerminalNode;
    RETURN(): TerminalNode;
    REVOKE(): TerminalNode;
    ROLE(): TerminalNode;
    ROLES(): TerminalNode;
    ROW(): TerminalNode;
    ROWS(): TerminalNode;
    SCAN(): TerminalNode;
    SEC(): TerminalNode;
    SECOND(): TerminalNode;
    SECONDARY(): TerminalNode;
    SECONDARIES(): TerminalNode;
    SECONDS(): TerminalNode;
    SEEK(): TerminalNode;
    SERVER(): TerminalNode;
    SERVERS(): TerminalNode;
    SET(): TerminalNode;
    SETTING(): TerminalNode;
    SETTINGS(): TerminalNode;
    SHORTEST(): TerminalNode;
    SHORTEST_PATH(): TerminalNode;
    SHOW(): TerminalNode;
    SIGNED(): TerminalNode;
    SINGLE(): TerminalNode;
    SKIPROWS(): TerminalNode;
    START(): TerminalNode;
    STARTS(): TerminalNode;
    STATUS(): TerminalNode;
    STOP(): TerminalNode;
    STRING(): TerminalNode;
    SUPPORTED(): TerminalNode;
    SUSPENDED(): TerminalNode;
    TARGET(): TerminalNode;
    TERMINATE(): TerminalNode;
    TEXT(): TerminalNode;
    THEN(): TerminalNode;
    TIME(): TerminalNode;
    TIMESTAMP(): TerminalNode;
    TIMEZONE(): TerminalNode;
    TO(): TerminalNode;
    TOPOLOGY(): TerminalNode;
    TRANSACTION(): TerminalNode;
    TRANSACTIONS(): TerminalNode;
    TRAVERSE(): TerminalNode;
    TRUE(): TerminalNode;
    TYPE(): TerminalNode;
    TYPES(): TerminalNode;
    UNION(): TerminalNode;
    UNIQUE(): TerminalNode;
    UNIQUENESS(): TerminalNode;
    UNWIND(): TerminalNode;
    URL(): TerminalNode;
    USE(): TerminalNode;
    USER(): TerminalNode;
    USERS(): TerminalNode;
    USING(): TerminalNode;
    VALUE(): TerminalNode;
    VARCHAR(): TerminalNode;
    VERBOSE(): TerminalNode;
    VERTEX(): TerminalNode;
    WAIT(): TerminalNode;
    WHEN(): TerminalNode;
    WHERE(): TerminalNode;
    WITH(): TerminalNode;
    WITHOUT(): TerminalNode;
    WRITE(): TerminalNode;
    XOR(): TerminalNode;
    YIELD(): TerminalNode;
    ZONED(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
export declare class EndOfFileContext extends ParserRuleContext {
    constructor(parser?: CypherParser, parent?: ParserRuleContext, invokingState?: number);
    EOF(): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CypherParserListener): void;
    exitRule(listener: CypherParserListener): void;
    accept<Result>(visitor: CypherParserVisitor<Result>): Result;
}
