import type { ParserRuleContext, Token } from 'antlr4';
import { CommonTokenStream } from 'antlr4';
import CypherParser, { StatementsContext } from './generated-parser/CypherParser';
import { SyntaxDiagnostic } from './highlighting/syntaxValidation/syntaxValidationHelpers';
export interface ParsingResult {
    query: string;
    parser: CypherParser;
    tokens: Token[];
    result: StatementsContext;
}
export declare enum LabelType {
    nodeLabelType = "Label",
    relLabelType = "Relationship type",
    unknown = "Label or relationship type"
}
export type LabelOrRelType = {
    labeltype: LabelType;
    labelText: string;
    couldCreateNewLabel: boolean;
    line: number;
    column: number;
    offsets: {
        start: number;
        end: number;
    };
};
export interface EnrichedParsingResult extends ParsingResult {
    errors: SyntaxDiagnostic[];
    stopNode: ParserRuleContext;
    collectedLabelOrRelTypes: LabelOrRelType[];
    collectedVariables: string[];
}
export interface ParsingScaffolding {
    query: string;
    parser: CypherParser;
    tokenStream: CommonTokenStream;
}
export declare function createParsingScaffolding(query: string): ParsingScaffolding;
export declare function parse(cypher: string): StatementsContext;
export declare function createParsingResult(parsingScaffolding: ParsingScaffolding): ParsingResult;
declare class ParserWrapper {
    parsingResult?: EnrichedParsingResult;
    parse(query: string): EnrichedParsingResult;
}
export declare const parserWrapper: ParserWrapper;
export {};
